<?php
/**
 * Offshore Theme Customizer.
 *
 * @package OffshoreCore
 */


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 *
 * @return array
 */
function offshore_kirki_configuration( $config ) {
    return wp_parse_args( array(
        'logo_image'   => plugin_dir_url( __FILE__ ) . 'assets/images/logo.png',
        'description'  => esc_attr__( 'The theme description.', 'offshorecore' ),
        'color_accent' => '#093EAE',
        'color_back'   => '#f4f5f8',
        'disable_loader' => true
    ), $config );
}
add_filter( 'kirki/config', 'offshore_kirki_configuration' );
/**
 * Add the theme configuration
 */
Offshore_Kirki::add_config( 'offshore_theme', array(
    'option_type' => 'theme_mod',
    'capability'  => 'edit_theme_options',
) );

Offshore_Kirki::add_panel( 'offshore_typography', array(
    'priority'    => 10,
    'title'       => __( 'Offshore Typography', 'offshorecore' ),
    // 'description' => __( 'My Description', 'textdomain' ),
) );

Offshore_Kirki::add_panel( 'offshore_panel', array(
    'priority'    => 10,
    'title'       => __( 'Offshore Options', 'offshorecore' ),
    // 'description' => __( 'My Description', 'textdomain' ),
) );
/**
 * Add the typography section
 */
Offshore_Kirki::add_section( 'body_typography', array(
    'title'      => esc_attr__( 'Body Typography', 'offshorecore' ),
    'panel'     =>  'offshore_typography',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );
Offshore_Kirki::add_section( 'header_typography', array(
    'title'      => esc_attr__( 'Header Typography', 'offshorecore' ),
    'panel'     =>  'offshore_typography',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

/**
 * Add the body-typography control
 */
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'body_typography',
    'label'       => esc_attr__( 'Body Typography', 'offshorecore' ),
    'description' => esc_attr__( 'Select the main typography options for your site.', 'offshorecore' ),
    'help'        => esc_attr__( 'The typography options you set here apply to all content on your site.', 'offshorecore' ),
    'section'     => 'body_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto',
        'variant'        => '400',
        'font-size'      => '16px',
        'line-height'    => '1.2',
        // 'letter-spacing' => '0',
        'color'          => '#677078',
    ),
    'output' => array(
        array(
            'element' => 'body',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h1_typography',
    'label'       => esc_attr__( 'H1 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H1 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '36px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h1',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h2_typography',
    'label'       => esc_attr__( 'H2 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H2 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '30px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h2',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h3_typography',
    'label'       => esc_attr__( 'H3 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H3 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '24px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h3',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h4_typography',
    'label'       => esc_attr__( 'H4 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H4 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '18px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h4',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h5_typography',
    'label'       => esc_attr__( 'H5 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H5 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '14px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h5',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'h6_typography',
    'label'       => esc_attr__( 'H6 Headers Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all H6 Headers.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '500',
        'font-size'      => '12px',
        'line-height'    => '1.1',
        // 'letter-spacing' => '0',
        'color'          => '#2a2a2a',
    ),
    'output' => array(
        array(
            'element' => 'h6',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'typography',
    'settings'    => 'post_title_typography',
    'label'       => esc_attr__( 'Post Title Typography', 'offshorecore' ),
    'description' => esc_attr__( 'These settings control the typography for all post/page titles.', 'offshorecore' ),
    'section'     => 'header_typography',
    'priority'    => 10,
    'default'     => array(
        'font-family'    => 'Roboto Condensed',
        'variant'        => '700',
        'font-size'      => '50px',
        'line-height'    => '1.26',
        // 'letter-spacing' => '0',
        'color'          => '#ffffff',
    ),
    'output' => array(
        array(
            'element' => '.page-title h2.title',
        ),
    ),
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'header_background',
    'label'       => __( 'Header Background Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#FFFFFF',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => '.logo-top-info',
            'property' => 'background-color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'nav_background',
    'label'       => __( 'Nav Background Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#f4f5f8',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => '.main-menu',
            'property' => 'background-color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'nav_text_color',
    'label'       => __( 'Nav Text Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#61656F',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => 'ul.main-menu li a',
            'property' => 'color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'body_background',
    'label'       => __( 'Body Background Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#FFFFFF',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => 'body',
            'property' => 'background-color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'primary_color',
    'label'       => __( 'Primary Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#093eb6',
    'priority'    => 10,
    'alpha'       => false,
    'output' => array(
        array(
            'element' => 'a, .top-info h3, ul.main-menu li a:hover, ul.main-menu li.active > a, .breadcrumbs a:hover, h4.subtitle, h2.title-2, .stats-info h4.counter, h4.client-name, .blog-content h3 a:hover, .blog-content a, .panel-default>.panel-heading a, .download-file a, ul.download-list li, .culture h2.culture-title, .sidebar-fact h3, .skill-bar-percent, .error-page h1, .nav-tabs>li>a, .top-widgets h3, .comment-respond h3.comment-reply-title, .widget_categories ul li a:hover, .widget_archive ul li a:hover',
            'property' => 'color'
        ),
        array(
            'element' => '.btn-primary, .social ul.social-icons li a:hover, .links .btn-primary:hover, .news .blog-date, button.btn.btn-warning, .sidebar-download .download-file, .quote-post blockquote, .drop-caps.blue p:first-child::first-letter, .top-widgets ul.social-icons li a:hover, .comment-respond .form-submit #submit, .btn-secondary:hover, .publication-downloads h2, .wpcf7-submit.btn.btn-warning, .drop-cap.blue',
            'property' => 'background-color'
        ),
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'secondary_color',
    'label'       => __( 'Secondary Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#FFDA44',
    'priority'    => 10,
    'alpha'       => false,
    'output' => array(
        array(
            'element' => 'a.link, ul.download-list li a:hover, .feature-box .icon-container .fa, .list-bordered li i.fa, .services-other .img-box .fa',
            'property' => 'color'
        ),
        array(
            'element' => 'blockquote, .btn-default, .flex-control-paging li a.flex-active, .slider-content .primary-btn, h2.color-title, .career-box, .response-btn a.btn, .contact-box, .pre-footer > div:nth-child(2n) .contact-box, .pre-footer > div:nth-child(3n) .contact-box, .widgets-social a, .contact-map ul.nav-pills li a:hover, .contact-map ul.nav-pills li a:focus, .contact-map ul.nav-pills li.active a, .contact-map ul.nav-pills li.active a:hover, .contact-map ul.nav-pills li.active a:focus, .contact-map ul.nav-pills li a:hover, .cta, .sidebar-fact a.btn, .open-positions ul li a.btn, .skillbar-bar, .skillbar-bar:after, .drop-caps p:first-child::first-letter, .sk-cube-grid .sk-cube, .label-default, .drop-cap, .slider-btn, .newsletter button',
            'property' => 'background-color'
        ),
        array(
            'element' => '.services-other .img-box',
            'property' => 'border-color'
        ),
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'text_color',
    'label'       => __( 'Text Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#677078',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => 'p, .top-widgets p',
            'property' => 'color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
	'type'        => 'color',
	'settings'    => 'footer_text_color',
	'label'       => __( 'Footer Text Color', 'offshorecore' ),
	'section'     => 'colors',
	'default'     => '#677078',
	'priority'    => 10,
	'alpha'       => true,
	'output' => array(
		array(
			'element' => '.footer-widgets, .footer-widgets p',
			'property' => 'color'
		)
	),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
	'type'        => 'color',
	'settings'    => 'footer_link_color',
	'label'       => __( 'Footer Link Color', 'offshorecore' ),
	'section'     => 'colors',
	'default'     => 'rgba(255, 255, 255, 0.5)',
	'priority'    => 10,
	'alpha'       => true,
	'output' => array(
		array(
			'element' => 'footer .pre-footer:not a, footer ul li a, .footer-widgets .widgets-social:not a .widgets-social:not a, .footer-widgets ul li a',
			'property' => 'color'
		)
	),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
	'type'        => 'color',
	'settings'    => 'footer_title_color',
	'label'       => __( 'Footer Title Color', 'offshorecore' ),
	'section'     => 'colors',
	'default'     => '#ffffff',
	'priority'    => 10,
	'alpha'       => true,
	'output' => array(
		array(
			'element' => 'footer h2.widget-title, footer h1, footer h2, footer h3, footer h4, footer h5, footer h6',
			'property' => 'color'
		)
	),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'footer_background',
    'label'       => __( 'Footer Background Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#03153e',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => 'footer .footer',
            'property' => 'background-color'
        )
    ),
) );
Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'color',
    'settings'    => 'footer_copyright_background',
    'label'       => __( 'Footer Copyright Background Color', 'offshorecore' ),
    'section'     => 'colors',
    'default'     => '#020e28',
    'priority'    => 10,
    'alpha'       => true,
    'output' => array(
        array(
            'element' => 'footer .copyright',
            'property' => 'background-color'
        )
    ),
) );


/**
 * Add the global options section
 */
Offshore_Kirki::add_section( 'page', array(
    'title'      => esc_attr__( 'Global Page Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'select',
    'settings'    => 'page_template',
    'label'       => __( 'Default Template', 'offshorecore' ),
    'section'     => 'page',
    'default'     => 'right-sidebar',
    'priority'    => 10,
    'multiple'    => 1,
    'choices'     => array(
        'right-sidebar' => esc_attr__( 'Default - Right Sidebar', 'offshorecore' ),
        'left-sidebar' => esc_attr__( 'Left Sidebar', 'offshorecore' ),
        'no-sidebar' => esc_attr__( 'No Sidebar', 'offshorecore' ),
        'full-width' => esc_attr__( 'Full Width', 'offshorecore' )
    ),
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'toggle',
    'settings'    => 'hide_share_buttons',
    'label'       => __( 'Hide Share Buttons', 'offshorecore' ),
    'section'     => 'page',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Hide share buttons from posts.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'offshore_theme', array(
    'type'        => 'toggle',
    'settings'    => 'hide_post_author_box',
    'label'       => __( 'Hide Post Author Box', 'offshorecore' ),
    'section'     => 'page',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Hide post author box.', 'offshorecore' )
) );

Offshore_Kirki::add_section( 'header', array(
    'title'      => esc_attr__( 'Global Header Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

Offshore_Kirki::add_field( 'header_widgets', array(
    'type'        => 'toggle',
    'settings'    => 'hide_header_widgets',
    'label'       => __( 'Hide Header Widgets', 'offshorecore' ),
    'section'     => 'header',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'breadcrumbs', array(
    'type'        => 'toggle',
    'settings'    => 'hide_breadcrumbs',
    'label'       => __( 'Hide Breadcrumbs', 'offshorecore' ),
    'section'     => 'header',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'title_area', array(
    'type'        => 'toggle',
    'settings'    => 'hide_title_area',
    'label'       => __( 'Hide Title Area', 'offshorecore' ),
    'section'     => 'header',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_section( 'footer', array(
    'title'      => esc_attr__( 'Global Footer Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

Offshore_Kirki::add_field( 'pre_footer_widgets', array(
    'type'        => 'toggle',
    'settings'    => 'hide_pre_footer_widgets',
    'label'       => __( 'Hide Pre Footer Widgets', 'offshorecore' ),
    'section'     => 'footer',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'footer_widgets', array(
    'type'        => 'toggle',
    'settings'    => 'hide_footer_widgets',
    'label'       => __( 'Hide Footer Widgets', 'offshorecore' ),
    'section'     => 'footer',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'copyright_area', array(
    'type'        => 'toggle',
    'settings'    => 'hide_copyright_area',
    'label'       => __( 'Hide Copyright Area', 'offshorecore' ),
    'section'     => 'footer',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );

Offshore_Kirki::add_field( 'footer', array(
    'type'        => 'toggle',
    'settings'    => 'hide_footer',
    'label'       => __( 'Hide Footer', 'offshorecore' ),
    'section'     => 'footer',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Can be overridden from page options.', 'offshorecore' )
) );


Offshore_Kirki::add_section( 'services', array(
    'title'      => esc_attr__( 'Services Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );
Offshore_Kirki::add_field( 'archive_template', array(
    'type'        => 'select',
    'settings'    => 'services_archive_template',
    'label'       => __( 'Archive Template', 'offshorecore' ),
    'section'     => 'services',
    'default'     => 'global',
    'priority'    => 10,
    'multiple'    => 1,
    'choices'     => array(
        'global' => esc_attr__( 'Global', 'offshorecore' ),
        'right-sidebar' => esc_attr__( 'Right Sidebar', 'offshorecore' ),
        'left-sidebar' => esc_attr__( 'Left Sidebar', 'offshorecore' ),
        'no-sidebar' => esc_attr__( 'No Sidebar', 'offshorecore' ),
        'full-width' => esc_attr__( 'Full Width', 'offshorecore' )
    ),
) );


Offshore_Kirki::add_section( 'career', array(
    'title'      => esc_attr__( 'Career Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );
Offshore_Kirki::add_field( 'department', array(
    'type'     => 'text',
    'settings' => 'department_text',
    'label'    => __( 'Department Text', 'offshorecore' ),
    'description' => __( 'Insert text to replace "DEPARTMENT" text at the top of single career post.', 'offshorecore' ),
    'section'  => 'career',
    'default'  => '',
    'priority' => 10,
) );
Offshore_Kirki::add_field( 'location', array(
    'type'     => 'text',
    'settings' => 'location_text',
    'label'    => __( 'Location Text', 'offshorecore' ),
    'description' => __( 'Insert text to replace "LOCATION" text at the top of single career post.', 'offshorecore' ),
    'section'  => 'career',
    'default'  => '',
    'priority' => 10,
) );
Offshore_Kirki::add_field( 'education', array(
    'type'     => 'text',
    'settings' => 'education_text',
    'label'    => __( 'Education Text', 'offshorecore' ),
    'description' => __( 'Insert text to replace "EDUCATION" text at the top of single career post.', 'offshorecore' ),
    'section'  => 'career',
    'default'  => '',
    'priority' => 10,
) );
Offshore_Kirki::add_field( 'experience', array(
    'type'     => 'text',
    'settings' => 'experience_text',
    'label'    => __( 'Experience Text', 'offshorecore' ),
    'description' => __( 'Insert text to replace "EXPERIENCE" text at the top of single career post.', 'offshorecore' ),
    'section'  => 'career',
    'default'  => '',
    'priority' => 10,
) );

/**
 * Other Options
 */

Offshore_Kirki::add_section( 'other', array(
    'title'      => esc_attr__( 'Other Options', 'offshorecore' ),
    'panel'     =>  'offshore_panel',
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );
Offshore_Kirki::add_field( 'metadata', array(
    'type'        => 'toggle',
    'settings'    => 'hide_metadata',
    'label'       => __( 'Disable Meta Data', 'offshorecore' ),
    'section'     => 'other',
    'default'     => '0',
    'priority'    => 10,
    'description'   =>  __( 'Disable meta data from head section. Helpful in case you are using any SEO plugin.', 'offshorecore' )
) );
Offshore_Kirki::add_field( 'department', array(
    'type'     => 'text',
    'settings' => 'gmaps_api_key',
    'label'    => __( 'Google Maps API Key', 'offshorecore' ),
    'description' => __( 'Instructions on how to get an API key can be found here - https://developers.google.com/maps/documentation/javascript/get-api-key#key.', 'offshorecore' ),
    'section'  => 'other',
    'default'  => '',
    'priority' => 10,
) );
