<?php
/**
 * Register metaboxes
 */
class Offshore_Meta_Boxes {
 
    /**
     * Constructor.
     */
    public function __construct() {
        if ( is_admin() ) {
            add_action( 'load-post.php',     array( $this, 'init_metabox' ) );
            add_action( 'load-post-new.php', array( $this, 'init_metabox' ) );
        }
 
    }
 
    /**
     * Meta box initialization.
     */
    public function init_metabox() {
        add_action( 'add_meta_boxes', array( $this, 'add_metabox'  )        );
        add_action( 'save_post',      array( $this, 'save_metabox' ), 10, 2 );
    }
 
    /**
     * Adds the meta box.
     */
    public function add_metabox() {
        add_meta_box(
            'offshore-options-metabox',
            __( 'Offshore Options', 'offshore' ),
            array( $this, 'render_metabox' ),
            array( 'post', 'page', 'career', 'services', 'testimonial' ),
            'normal',
            'high'
        );
    }

    public function get_sidebars() {
        global $wp_registered_sidebars;
        $array = array( 'sidebar' => __( 'Default', 'offshore' ) );
        foreach ( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {
            $array[ $sidebar['id'] ] = ucwords( $sidebar['name'] );
        }
        return $array;
    }
 
    /**
     * Renders the meta box.
     */
    public function render_metabox( $post ) {
        // Add nonce for security and authentication.
        wp_nonce_field( 'offshore_save_options', 'offshore_options_nonce' );
        $screen = get_current_screen();
        ?>
            <script type="text/javascript">
                jQuery(document).ready(function($){
                    jQuery('#offshore-tabs').on('click', '.offshore-tab-nav', function(){
                        $(this).addClass('active')
                                .siblings().removeClass('active');
                        var content = $(this).data('target');
                        $('#'+content).siblings().hide();
                        $('#'+content).fadeIn();
                    });
                });
            </script>
            <style type="text/css">
                #offshore-options-metabox .inside {
                    margin: 0;
                    padding: 0;
                }
                #offshore-tabs .offshore-section {
                    overflow: hidden;
                    position: relative;
                }
                #offshore-tabs ul {
                    padding-bottom: 32768px;
                    margin-bottom: -32768px!important;
                    background-color: #f4f5f8;
                }
                #offshore-tabs .offshore-col {
                    margin-top: 0;
                    margin-bottom: 0;
                }
                #offshore-tabs .offshore-col .label {
                    margin-top: 0;
                }
                #offshore-tabs .offshore-col em {
                    color: #b7b7b7;
                    font-weight: 300;
                }
                #offshore-tabs ul {
                    display: inline-block;
                    width: 100%;
                    border-right: 1px solid #cecece;
                    box-shadow: 0 7px 15px #cecece;
                    -webkit-box-shadow: 0 7px 15px #cecece;
                    -moz-box-shadow: 0 7px 15px #cecece;
                }
                #offshore-tabs ul li {
                    margin-bottom: 0;
                }
                #offshore-tabs ul li.active a {
                    position: relative;
                    background-color: #093EB6;
                    color: #fff;
                }
                #offshore-tabs ul li.active a:after {
                    left: 100%;
                    top: 50%;
                    border: solid transparent;
                    content: " ";
                    height: 0;
                    width: 0;
                    position: absolute;
                    pointer-events: none;
                    border-color: rgba(9, 62, 182, 0);
                    border-left-color: #093EB6;
                    border-width: 14px;
                    margin-top: -14px;
                }
                #offshore-tabs ul li a {
                    display: inline-block;
                    width: 100%;
                    padding: 15px 0;
                    font-size: 14px;
                    background-color: #f4f5f8;
                    text-align: center;
                    border-bottom: 1px solid #CECECE;
                    text-decoration: none;
                }
                #offshore-tabs ul li a:focus {
                    outline: none;
                    box-shadow: none;
                    -moz-box-shadow: none;
                    -webkit-box-shadow: none;
                }
                #offshore-tabs .offshore-tab-content {
                    padding: 20px 20px 20px 0;
                }
                #offshore-tabs .offshore-tab-content > div > div {
                    padding-top: 0;
                }
                #offshore-tabs .offshore-text {
                    margin: 0;
                }
                #offshore-tabs input, #offshore-tabs textarea, #offshore-tabs select {
                    max-width: 100%;
                }
            </style>
            <div id="offshore-tabs">
                <div class="offshore-section offshore-group">
                    <div class="offshore-col offshore-span_2_of_12">
                        <ul style="margin:0;">
                        <?php if( $screen->id != 'testimonial' ){ ?>
                            <li class="offshore-tab-nav active" data-target="offshore-page-tab">
                                <a href="javascript:void(0)"><?php _e( 'Page', 'offshore' ); ?></a>
                            </li>
                            <li class="offshore-tab-nav" data-target="offshore-header-tab">
                                <a href="javascript:void(0)"><?php _e( 'Header', 'offshore' ); ?></a>
                            </li>
                            <?php 
                                if( $post->ID == get_option( 'page_on_front' ) ){ ?>
                                    <li class="offshore-tab-nav" data-target="offshore-slider-tab">
                                        <a href="javascript:void(0)"><?php _e( 'Slider', 'offshore' ); ?></a>
                                    </li>
                            <?php } ?>
                            <li class="offshore-tab-nav" data-target="offshore-sidebar-tab">
                                <a href="javascript:void(0)"><?php _e( 'Sidebar', 'offshore' ); ?></a>
                            </li>
                            <li class="offshore-tab-nav" data-target="offshore-footer-tab">
                                <a href="javascript:void(0)"><?php _e( 'Footer', 'offshore' ); ?></a>
                            </li>
                            <?php 
                                if( $screen->id == 'career' ){
                                    echo '<li class="offshore-tab-nav" data-target="offshore-apply-job-button-tab">
                                <a href="javascript:void(0)">' . __( 'Apply Job', 'offshore' ) . '</a>
                            </li>';
                                }
                            } else { ?>
                                <li class="offshore-tab-nav active" data-target="offshore-testimonial-tab">
                                <a href="javascript:void(0)"><?php _e( 'Testimonial', 'offshore' ); ?></a>
                            </li>
                            <?php } ?>
                        </ul>
                    </div>
                    <div class="offshore-col offshore-span_10_of_12 offshore-bg-gray">
                        <div class="offshore-tab-content offshore-sc-form">       
                            <?php 

                                if( class_exists('OffshoreFormElements') ){
                                    $form = new OffshoreFormElements();
                                    $meta = get_post_meta( $post->ID, 'offshore_options', true );
                                    if( $screen->id != 'testimonial' ){
                                        echo '<div id="offshore-page-tab">';

                                            $form->input( array(
                                                'type'              =>  'textarea',
                                                'name'              =>  'description',
                                                'placeholder'       =>  __( 'Your content here..', 'offshore' ),
                                                'label'             =>  __( 'Page Description', 'offshore' ),
                                                'description'       => __( 'Insert page description. This will be shown below page title.', 'offshore' ),
                                                'value'             =>  isset( $meta['description'] ) ? $meta['description'] : ''
                                            ) );
                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'template',
                                                'label'             =>  __( 'Page Layout', 'offshore' ),
                                                'description'       => __( 'Select the required layout.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'right-sidebar' => __( 'Right Sidebar', 'offshore' ),
                                                    'left-sidebar' => __( 'Left Sidebar', 'offshore' ),
                                                    'no-sidebar' => __( 'No Sidebar', 'offshore' ),
                                                    'full-width' => __( 'Full Width', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['template'] ) ? $meta['template'] : ''
                                            ) );
                                            if( $screen->id == 'post' ){
                                                $form->input( array(
                                                    'type'              =>  'select',
                                                    'name'              =>  'hide_share_buttons',
                                                    'label'             =>  __( 'Hide Share Buttons', 'offshore' ),
                                                    'description'       => __( 'Enable or Disable share buttons.', 'offshore' ),
                                                    'options'           =>  array(
                                                        'global' => __( 'Global', 'offshore' ),
                                                        'yes' => __( 'Yes', 'offshore' ),
                                                        'no' => __( 'No', 'offshore' ),
                                                    ),
                                                    'value'             =>  isset( $meta['hide_share_buttons'] ) ? $meta['hide_share_buttons'] : ''
                                                ) );
                                                $form->input( array(
                                                    'type'              =>  'select',
                                                    'name'              =>  'hide_post_author_box',
                                                    'label'             =>  __( 'Hide Post Author Box', 'offshore' ),
                                                    'description'       => __( 'Enable or Disable post author box.', 'offshore' ),
                                                    'options'           =>  array(
                                                        'global' => __( 'Global', 'offshore' ),
                                                        'yes' => __( 'Yes', 'offshore' ),
                                                        'no' => __( 'No', 'offshore' ),
                                                    ),
                                                    'value'             =>  isset( $meta['hide_post_author_box'] ) ? $meta['hide_post_author_box'] : ''
                                                ) );
                                            }

                                        echo '</div>';

                                        echo '<div id="offshore-header-tab" class="hidden">';

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_header_widgets',
                                                'label'             =>  __( 'Hide Widgets', 'offshore' ),
                                                'description'       => __( 'Enable or Disable top widgets.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_header_widgets'] ) ? $meta['hide_header_widgets'] : ''
                                            ) );
                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_menu',
                                                'label'             =>  __( 'Hide Navigation Menu', 'offshore' ),
                                                'description'       => __( 'Enable or Disable navigation menu.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_menu'] ) ? $meta['hide_menu'] : ''
                                            ) );
                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_title_area',
                                                'label'             =>  __( 'Hide Title Area', 'offshore' ),
                                                'description'       => __( 'Enable or Disable title area.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_title_area'] ) ? $meta['hide_title_area'] : ''
                                            ) );
                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_breadcrumbs',
                                                'label'             =>  __( 'Hide Breadcrumbs', 'offshore' ),
                                                'description'       => __( 'Enable or Disable breadcrumbs.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_breadcrumbs'] ) ? $meta['hide_breadcrumbs'] : ''
                                            ) );
                                            $menus = array( 'global' => __( 'Global', 'offshore' ) );
                                            $menu_locations = get_terms( 'nav_menu', array( 'hide_empty' => true ) );
                                            // var_dump($menu_locations);
                                            foreach ( $menu_locations as $menu ) {
                                                $menus[ $menu->term_id ] = $menu->name;
                                            }
                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'main_menu',
                                                'label'             =>  __( 'Main Menu', 'offshore' ),
                                                'description'       => __( 'Select which menu displays on this page.', 'offshore' ),
                                                'options'           =>  $menus,
                                                'value'             =>  isset( $meta['main_menu'] ) ? $meta['main_menu'] : ''
                                            ) );

                                        echo '</div>';

                                        if( $post->ID == get_option( 'page_on_front' ) ){
                                            echo '<div id="offshore-slider-tab" class="hidden">';

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'rev_slider',
                                                'label'             =>  __( 'Hide Revolution Slider', 'offshore' ),
                                                'description'       => __( 'Enable or Disable slider.', 'offshore' ),
                                                'options'           =>  array(
                                                    'no' => __( 'No', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['rev_slider'] ) ? $meta['rev_slider'] : ''
                                            ) );

                                            $rev_sliders = array();
                                            if( class_exists('RevSlider') ){
                                                $sld = new RevSlider();
                                                $sliders = $sld->getArrSliders();
                                                foreach( $sliders as $slider ) {
                                                    $rev_sliders[ $slider->getAlias() ] = $slider->getTitle();
                                                }
                                            }

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'rev_slider_alias',
                                                'label'             =>  __( 'Revolution Slider Alias', 'offshore' ),
                                                'description'       => __( 'Select the slider you want to display.', 'offshore' ),
                                                'options'           =>  $rev_sliders,
                                                'value'             =>  isset( $meta['rev_slider_alias'] ) ? $meta['rev_slider_alias'] : ''
                                            ) );

                                            echo '</div>';
                                        }

                                        echo '<div id="offshore-sidebar-tab" class="hidden">';

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'sidebar',
                                                'label'             =>  __( 'Select Sidebar', 'offshore' ),
                                                'description'       => __( 'Select the sidebar to display on this page.', 'offshore' ),
                                                'options'           =>  $this->get_sidebars(),
                                                'value'             =>  isset( $meta['sidebar'] ) ? $meta['sidebar'] : ''
                                            ) );

                                        echo '</div>';

                                        echo '<div id="offshore-footer-tab" class="hidden">';

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_pre_footer_widgets',
                                                'label'             =>  __( 'Hide Pre Footer Widgets', 'offshore' ),
                                                'description'       => __( 'Enable or Disable pre footer widgets.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_pre_footer_widgets'] ) ? $meta['hide_pre_footer_widgets'] : ''
                                            ) );

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_footer_widgets',
                                                'label'             =>  __( 'Hide Footer Widgets', 'offshore' ),
                                                'description'       => __( 'Enable or Disable footer widgets.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_footer_widgets'] ) ? $meta['hide_footer_widgets'] : ''
                                            ) );

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_copyright_area',
                                                'label'             =>  __( 'Hide Copyright Area', 'offshore' ),
                                                'description'       => __( 'Enable or Disable copywrite area.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_copyright_area'] ) ? $meta['hide_copyright_area'] : ''
                                            ) );

                                            $form->input( array(
                                                'type'              =>  'select',
                                                'name'              =>  'hide_footer_area',
                                                'label'             =>  __( 'Hide Footer area', 'offshore' ),
                                                'description'       => __( 'Enable or Disable footer area.', 'offshore' ),
                                                'options'           =>  array(
                                                    'global' => __( 'Global', 'offshore' ),
                                                    'yes' => __( 'Yes', 'offshore' ),
                                                    'no' => __( 'No', 'offshore' ),
                                                ),
                                                'value'             =>  isset( $meta['hide_footer_area'] ) ? $meta['hide_footer_area'] : ''
                                            ) );

                                        echo '</div>';

                                        if( $screen->id == 'career' ){

                                            $wcf7 = array();
                                            $args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
                                            if( $cf7Forms = get_posts( $args ) ){
                                                foreach($cf7Forms as $cf7Form){
                                                    $wcf7[ $cf7Form->ID ] = $cf7Form->post_title;
                                                }
                                            }

                                            echo '<div id="offshore-apply-job-button-tab" class="hidden">';
                                                $form->input( array(
                                                    'type'              =>  'select',
                                                    'name'              =>  'apply_job_button',
                                                    'label'             =>  __( 'Apply To Job Button', 'offshore' ),
                                                    'description'       => __( 'Select whether to show or hide apply to job button.', 'offshore' ),
                                                    'options'           =>  array(
                                                        'yes'   => __( 'Yes', 'offshore' ),
                                                        'no'    => __( 'No', 'offshore' ),
                                                    ),
                                                    'value'             =>  isset( $meta['apply_job_button'] ) ? $meta['apply_job_button'] : ''
                                                ) );
                                                $form->input( array(
                                                    'type'              =>  'select',
                                                    'name'              =>  'apply_job_button_type',
                                                    'label'             =>  __( 'Button Type', 'offshore' ),
                                                    'description'       => __( 'Select whether to add a custom link or use default popup based form.', 'offshore' ),
                                                    'options'           =>  array(
                                                        'default'   => __( 'Default', 'offshore' ),
                                                        'link'    => __( 'Link', 'offshore' ),
                                                    ),
                                                    'value'             =>  isset( $meta['apply_job_button_type'] ) ? $meta['apply_job_button_type'] : ''
                                                ) );
                                                $form->input( array(
                                                    'type'              =>  'text',
                                                    'name'              =>  'apply_job_button_link',
                                                    'label'             =>  __( 'Button Link', 'offshore' ),
                                                    'description'       => __( 'Insert button link if you want to redirect user to some other website for applying to this job. It works only if "Job Type" is set to "Link" above.', 'offshore' ),
                                                    'value'             =>  isset( $meta['apply_job_button_link'] ) ? $meta['apply_job_button_link'] : ''
                                                ) );
                                                $form->input( array(
                                                    'type'              =>  'select',
                                                    'name'              =>  'apply_job_button_wpcf7',
                                                    'label'             =>  __( 'Contact Form 7 Form', 'offshore' ),
                                                    'description'       => __( 'Select the form to open in popup.', 'offshore' ),
                                                    'options'           =>  $wcf7,
                                                    'value'             =>  isset( $meta['apply_job_button_wpcf7'] ) ? $meta['apply_job_button_wpcf7'] : ''
                                                ) );
                                                $form->input( array(
                                                    'type'              =>  'text',
                                                    'name'              =>  'apply_job_button_text',
                                                    'label'             =>  __( 'Button Text', 'offshore' ),
                                                    'description'       => __( 'Insert button text or leave empty for default text.', 'offshore' ),
                                                    'value'             =>  isset( $meta['apply_job_button_text'] ) ? $meta['apply_job_button_text'] : ''
                                                ) );
                                            echo '</div>';
                                        }
                                    } else {
                                        echo '<div id="offshore-page-tab">';

                                            $form->input( array(
                                                'type'              =>  'text',
                                                'name'              =>  'testimonial_name',
                                                'label'             =>  __( 'Client Name', 'offshore' ),
                                                'description'       => __( 'Insert client name.', 'offshore' ),
                                                'value'             =>  isset( $meta['testimonial_name'] ) ? $meta['testimonial_name'] : ''
                                            ) );

                                            $form->input( array(
                                                'type'              =>  'text',
                                                'name'              =>  'testimonial_designation',
                                                'label'             =>  __( 'Client Designation', 'offshore' ),
                                                'description'       => __( 'Insert client designation.', 'offshore' ),
                                                'value'             =>  isset( $meta['testimonial_designation'] ) ? $meta['testimonial_designation'] : ''
                                            ) );

                                        echo '</div>';
                                    }
                                }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        
    }
 
    /**
     * Handles saving the meta box.
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @return null
     */
    public function save_metabox( $post_id, $post ) {
        // Add nonce for security and authentication.
        $nonce_name   = isset( $_POST['offshore_options_nonce'] ) ? $_POST['offshore_options_nonce'] : '';
        $nonce_action = 'offshore_save_options';
 
        // Check if nonce is set.
        if ( ! isset( $nonce_name ) ) {
            return;
        }
 
        // Check if nonce is valid.
        if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) ) {
            return;
        }
 
        // Check if user has permissions to save data.
        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }
 
        // Check if not an autosave.
        if ( wp_is_post_autosave( $post_id ) ) {
            return;
        }
                                                
        // Check if not a revision.
        if ( wp_is_post_revision( $post_id ) ) {
            return;
        }

        $options = array(
            'description' => isset( $_POST['description'] ) ? $_POST['description'] : '',
            'template' => isset( $_POST['template'] ) ? $_POST['template'] : '',
            'hide_share_buttons' => isset( $_POST['hide_share_buttons'] ) ? $_POST['hide_share_buttons'] : '',
            'hide_post_author_box' => isset( $_POST['hide_post_author_box'] ) ? $_POST['hide_post_author_box'] : '',
            'hide_header_widgets' => isset( $_POST['hide_header_widgets'] ) ? $_POST['hide_header_widgets'] : '',
            'hide_menu' => isset( $_POST['hide_menu'] ) ? $_POST['hide_menu'] : '',
            'hide_title_area' => isset( $_POST['hide_title_area'] ) ? $_POST['hide_title_area'] : '',
            'hide_breadcrumbs' => isset( $_POST['hide_breadcrumbs'] ) ? $_POST['hide_breadcrumbs'] : '',
            'rev_slider' => isset( $_POST['rev_slider'] ) ? $_POST['rev_slider'] : '',
            'rev_slider_alias' => isset( $_POST['rev_slider_alias'] ) ? $_POST['rev_slider_alias'] : '',
            'main_menu' => isset( $_POST['main_menu'] ) ? $_POST['main_menu'] : '',
            'sidebar' => isset( $_POST['sidebar'] ) ? $_POST['sidebar'] : '',
            'hide_pre_footer_widgets' => isset( $_POST['hide_pre_footer_widgets'] ) ? $_POST['hide_pre_footer_widgets'] : '',
            'hide_footer_widgets' => isset( $_POST['hide_footer_widgets'] ) ? $_POST['hide_footer_widgets'] : '',
            'hide_copyright_area' => isset( $_POST['hide_copyright_area'] ) ? $_POST['hide_copyright_area'] : '',
            'hide_footer_area' => isset( $_POST['hide_footer_area'] ) ? $_POST['hide_footer_area'] : '',
            'apply_job_button' => isset( $_POST['apply_job_button'] ) ? $_POST['apply_job_button'] : '',
            'apply_job_button_type' => isset( $_POST['apply_job_button_type'] ) ? $_POST['apply_job_button_type'] : '',
            'apply_job_button_link' => isset( $_POST['apply_job_button_link'] ) ? $_POST['apply_job_button_link'] : '',
            'apply_job_button_text' => isset( $_POST['apply_job_button_text'] ) ? $_POST['apply_job_button_text'] : '',
            'apply_job_button_wpcf7' => isset( $_POST['apply_job_button_wpcf7'] ) ? $_POST['apply_job_button_wpcf7'] : '',
            'testimonial_name' => isset( $_POST['testimonial_name'] ) ? $_POST['testimonial_name'] : '',
            'testimonial_designation' => isset( $_POST['testimonial_designation'] ) ? $_POST['testimonial_designation'] : '',
        );

        // Save meta data
        update_post_meta( $post_id, 'offshore_options', $options );
    }
}
 
new Offshore_Meta_Boxes();