<?php

class Offshore_Accordion {

    private $accordion_counter = 1;
    private $panel_counter = 1;
    private $accordion_id;

    function __construct() {
        add_shortcode( 'offshore_accordion', array( $this, 'parent' ) );
        add_shortcode( 'offshore_accordion_panel', array( $this, 'child' ) );
        if( has_action( 'vc_before_init' ) ){
            add_action( 'vc_before_init', array( $this, 'vc_parent' ) );
            add_action( 'vc_before_init', array( $this, 'vc_child' ) );
        }
    }

    function parent( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(

                '' => '',

            ), $atts));

        $id = sprintf( 'accordion-%s-%s', get_the_ID(), $this->accordion_counter );

        $this->accordion_id = $id;

        $output = sprintf( '<div class="panel-group" id="%s">%s</div>', $id, do_shortcode( $content ) );

        $output = preg_replace('~<br />~', '', $output); // Remove <br> tags

        $this->accordion_counter++;

        return $output;
    }

    function child( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(
                'title' => '',
                'open' => ''

            ), $atts));

        if( $open == 'yes' ){
            $active = ' in';
            $class = ' class="collapsed"';
        } else {
            $class = '';
            $active = '';
        }

        $id = substr( md5( sprintf( 'panel-%s-%s-%s', get_the_ID(), $this->accordion_counter, $this->panel_counter ) ), 15 );

        $output = sprintf( '<div class="panel panel-default">
            <div class="panel-heading">
                <h4 class="panel-title"> 
                    <a' . $class . ' data-toggle="collapse" data-parent="#%1$s" href="#%2$s">%3$s</a>
                </h4>
            </div>
            <div id="%2$s" class="panel-collapse collapse%4$s">
                <div class="panel-body">
                    %5$s
                </div>
            </div>
        </div>', $this->accordion_id, $id, $title, $active, wpautop( do_shortcode( $content ) ) );

        $this->panel_counter++;

        return $output;
    }

    function vc_parent() {
        vc_map( array(
            'name'        => __( 'Accordion', 'offshorecore' ),
            'description' => __( 'Add Accordion', 'offshorecore' ),
            'base'        => 'offshore_accordion',
            'class'       => 'offshore',
            'icon'        => 'fa fa-plus-square',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'show_settings_on_create' => false,
            'as_parent'       => array( 'only' => 'offshore_accordion_panel' ),
            'params'      => array(
            ),
            'js_view' => 'VcColumnView'
        ) );
    }

    function vc_child() {
        vc_map( array(
            'name'        => __( 'Accordion Panel', 'offshorecore' ),
            'description' => __( 'Add Accordion Panel', 'offshorecore' ),
            'base'        => 'offshore_accordion_panel',
            'class'       => 'offshore',
            'icon'        => 'fa fa-plus-square',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'as_child'       => array( 'only' => 'offshore_accordion' ),
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Title', 'offshorecore' ),
                    'param_name'  => 'title',
                    'description' => __( 'Insert the accordion panel title.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textarea_html',
                    'heading'     => __( 'Accordion Panel Content', 'offshorecore' ),
                    'param_name'  => 'content',
                    'description' => __( 'Insert the accordion panel content.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'dropdown',
                    'admin_label' => true,
                    'heading'     => __( 'Open by default', 'offshorecore' ),
                    'param_name'  => 'open',
                    'value'       => array(
                        __( 'No', 'offshorecore' ) => 'no',
                        __( 'Yes', 'offshorecore' ) => 'yes'
                    ),
                    'description' => __( 'Keep this panel open by default.', 'offshorecore' )
                )
            )
        ) );
    }

}

new Offshore_Accordion();

function offshore_accordion_parent_child() {
    if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
        class WPBakeryShortCode_offshore_accordion extends WPBakeryShortCodesContainer {
        }
    }
    if ( class_exists( 'WPBakeryShortCode' ) ) {
        class WPBakeryShortCode_offshore_accordion_panel extends WPBakeryShortCode {
        }
    }
}
add_action( 'plugins_loaded', 'offshore_accordion_parent_child' );