<?php

if ( !function_exists( 'offshore_contact_box_shortcode' ) ) {

    function offshore_contact_box_shortcode( $atts, $content = null ) {

        extract( shortcode_atts(

            array(

                'background_color' => '#ffda44',
                'icon' => '',
                'heading' => '',
                'text_color' => '#000'

            ), $atts));

        if( $background_color != '' ){
            $background_color = 'background-color:'. esc_attr( $background_color ) .';';
        }
        if( $text_color != '' ){
            $text_color = 'color:'. esc_attr( $text_color ) .';';
        }
        if( $icon != '' ){
            $icon = '<i class="fa '. esc_attr( $icon ) .'" aria-hidden="true" style="'. $text_color .'"></i>';
        }

        $style = ' style="' . $background_color . $text_color . '"';

        $output = '<div class="contact-box"' . $style . '>
                        ' . $icon . '
                        <div class="contact-details">
                            <h4 class="pre-footer-title" style="'. $text_color .'">' . esc_html( $heading ) . '</h4>
                            ' . wpautop( do_shortcode( $content ) ) . '
                        </div>
                    </div>';

        return $output;

    }

    add_shortcode( 'offshore_contact_box', 'offshore_contact_box_shortcode' );

}

if ( !function_exists( 'offshore_contact_box_large_shortcode' ) ) {

    function offshore_contact_box_large_shortcode( $atts, $content = null ) {

        extract( shortcode_atts(

            array(

                'heading' => '',
                'address' => '',
                'phone_number' => '',
                'email' => ''

            ), $atts));

        if( $heading != '' ){
            $heading = '<h4 class="contact-title subtitle">' . esc_html( $heading ) . '</h4>';
        }
        if( $address != '' ){
            $address = '<div class="address">
                            <i class="fa fa-map-marker" aria-hidden="true"></i>
                            <p>' . wp_kses_post( $address ) . '</p>
                        </div>';
        }
        if( $phone_number != '' ){
            $phone_number = '<div class="phone">
                            <i class="fa fa-phone" aria-hidden="true"></i>
                            <p>' . wp_kses_post( $phone_number ) . '</p>
                        </div>';
        }
        if( $email != '' ){
            $email = '<div class="email">
                            <i class="fa fa-envelope" aria-hidden="true"></i>
                            <p><a href="mailto:' . antispambot( $email ) . '">' . antispambot( $email ) . '</a> </p>
                        </div>';
        }

        $output = '<div class="contact-area-box">' . $heading . $address . $phone_number . $email . '</div>';

        return $output;

    }

    add_shortcode( 'offshore_contact_box_large', 'offshore_contact_box_large_shortcode' );

}


function offshore_vc_contact_box() {
    vc_map( array(
        'name'        => __( 'Contact Box', 'offshorecore' ),
        'description' => __( 'Add contact box', 'offshorecore' ),
        'base'        => 'offshore_contact_box',
        'class'       => 'offshore',
        'icon'        => 'fa fa-location-arrow',
        'category'    => __( 'Offshore', 'offshorecore' ),
        'params'      => array(
            array(
                'type'        => 'textfield',
                'admin_label' => true,
                'heading'     => __( 'Box Heading', 'offshorecore' ),
                'param_name'  => 'heading',
                'description' => __( 'Insert text for heading.', 'offshorecore' ),
                'value' => ''
            ),
            array(
                'type'        => 'textarea_html',
                'admin_label' => true,
                'heading'     => __( 'Box Content', 'offshorecore' ),
                'param_name'  => 'content',
                'description' => __( 'Insert address, phone numbers, etc. Eg. PO Box 16122, Collins Street West, Victoria 8007 Australia.', 'offshorecore' ),
                'value' => ''
            ),
            array(
                'type' => 'iconpicker',
                'admin_label' => true,
                'heading' => __( 'Box Icon', 'offshorecore' ),
                'param_name' => 'icon',
                'value' => 'fa fa-adjust', // default value to backend editor admin_label
                'settings' => array(
                    'emptyIcon' => true,
                    'iconsPerPage' => 4000,
                ),
                'description' => __( 'Select the required icon.', 'offshorecore' ),
            ),
            array(
                'type' => 'colorpicker',
                'heading' => __( 'Box Background Color', 'offshorecore' ),
                'param_name' => 'background_color',
                'value' => '',
                'description' => __( 'Select required background color.', 'offshorecore' ),
                'group' => __( 'Color', 'offshorecore' )
            ),
            array(
                'type' => 'colorpicker',
                'heading' => __( 'Box Text Color', 'offshorecore' ),
                'param_name' => 'text_color',
                'value' => '',
                'description' => __( 'Select required text color.', 'offshorecore' ),
                'group' => __( 'Color', 'offshorecore' )
            ),
        )
    ) );
}
function offshore_vc_contact_box_large() {
    vc_map( array(
        'name'        => __( 'Contact Box Large', 'offshorecore' ),
        'description' => __( 'Add contact box (large)', 'offshorecore' ),
        'base'        => 'offshore_contact_box_large',
        'class'       => 'offshore',
        'icon'        => 'fa fa-map-marker',
        'category'    => __( 'Offshore', 'offshorecore' ),
        'params'      => array(
            array(
                'type'        => 'textfield',
                'admin_label' => true,
                'heading'     => __( 'Box Heading', 'offshorecore' ),
                'param_name'  => 'heading',
                'description' => __( 'Insert text for heading.', 'offshorecore' ),
                'value' => ''
            ),
            array(
                'type'        => 'textarea',
                'admin_label' => true,
                'heading'     => __( 'Box Address', 'offshorecore' ),
                'param_name'  => 'address',
                'description' => __( 'Insert address. You can use tag to break text.', 'offshorecore' ),
                'value' => ''
            ),
            array(
                'type'        => 'textarea',
                'admin_label' => true,
                'heading'     => __( 'Box Phone Number', 'offshorecore' ),
                'param_name'  => 'phone_number',
                'description' => __( 'Insert phone number. You can use tag to break text.', 'offshorecore' ),
                'value' => ''
            ),
            array(
                'type'        => 'textarea',
                'admin_label' => true,
                'heading'     => __( 'Box Email', 'offshorecore' ),
                'param_name'  => 'email',
                'description' => __( 'Insert email address. You can use tag to break text.', 'offshorecore' ),
                'value' => ''
            ),
        )
    ) );
}

if( has_action( 'vc_before_init' ) ){
    add_action( 'vc_before_init', 'offshore_vc_contact_box' );
    add_action( 'vc_before_init', 'offshore_vc_contact_box_large' );
}
