<?php

class Offshore_Counter_Box {

    private $counter_box = false;

    function __construct() {

        add_shortcode( 'offshore_counter_box', array( $this, 'parent' ) );
        add_shortcode( 'offshore_counter', array( $this, 'child' ) );
        if( has_action( 'vc_before_init' ) ){
            add_action( 'vc_before_init', array( $this, 'vc_parent' ) );
            add_action( 'vc_before_init', array( $this, 'vc_child' ) );
        }

    }

    function parent( $atts, $content = '' ) {

        $this->counter_box = true;
        
        $content = do_shortcode( $content );

        $output = sprintf( '<div class="row stats stats-2">%s</div>', $content );

        $output = preg_replace('~<br />~', '', $output); // Remove <br> tags

        return $output;
    }

    function child( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(

                'value' => '',
                'icon' => '',
                'image' => '',
                'image_alt' => 'counter',

            ), $atts));

        $output = '';

        if( $this->counter_box ){
            $output .= '<div class="col-xs-6">';
        }

        $picture = '';

        if( $icon != '' ){
            $picture = '<span class="counter-icon fa '. $icon .'" style="font-size:77px;"></span>';
        }

        if( is_numeric( $image ) ){
            $attachment = wp_get_attachment_image_src( $image,'full' );
            $image = $attachment[0];
        }

        if( $image != '' ){
            $picture = '<img src="'. $image .'" class="counter-img" alt="'. $image_alt .'" />';
        }

        $output .= $picture . '<div class="stats-info">
                        <h4 class="counter">'. $value .'</h4>
                        '. wpautop( do_shortcode( $content ) ) .'
                    </div>';

        if( $this->counter_box ){
            $output .= '</div>';
        }

        return $output;
    }

    function vc_parent() {
        vc_map( array(
            'name'        => __( 'Counter Box', 'offshorecore' ),
            'description' => __( 'Adds counter box', 'offshorecore' ),
            'base'        => 'offshore_counter_box',
            'class'       => 'offshore',
            'icon'        => 'fa fa-comments',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'show_settings_on_create' => false,
            'is_container' => true,
            'as_parent'       => array( 'only' => 'offshore_counter' ),
            'params'      => array(
            ),
            'js_view' => 'VcColumnView'
        ) );
    }

    function vc_child() {
        vc_map( array(
            'name'        => __( 'Counter', 'offshorecore' ),
            'description' => __( 'Add a counter', 'offshorecore' ),
            'base'        => 'offshore_counter',
            'class'       => 'offshore',
            'icon'        => 'fa fa-comments',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'holder' => 'span',
                    'class'       => '',
                    'heading'     => __( 'Counter Value', 'offshorecore' ),
                    'param_name'  => 'value',
                    'description' => __( 'The value on which counter should stop.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textfield',
                    'class'       => '',
                    'heading'     => __( 'Counter Text', 'offshorecore' ),
                    'param_name'  => 'content',
                    'description' => __( 'Text to display below counter value.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => __( 'Counter Icon', 'offshorecore' ),
                    'param_name' => 'icon',
                    'value' => 'fa fa-adjust', // default value to backend editor admin_label
                    'settings' => array(
                        'emptyIcon' => true,
                        // default true, display an 'EMPTY' icon?
                        'iconsPerPage' => 4000,
                        // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
                    ),
                    'description' => __( 'Select the required icon.', 'offshorecore' ),
                ),
                array(
                    'type'        => 'attach_image',
                    'class'       => '',
                    'heading'     => __( 'Counter Image', 'offshorecore' ),
                    'param_name'  => 'image',
                    'description' => __( 'Select the image which will be on the left of counter value. This overrides counter icon.', 'offshorecore' ),
                    'value' => ''
                ),
            )
        ) );
    }

}

new Offshore_Counter_Box();

function offshore_counter_box_parent_child() {
    if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
        class WPBakeryShortCode_offshore_counter_box extends WPBakeryShortCodesContainer {
        }
    }
    if ( class_exists( 'WPBakeryShortCode' ) ) {
        class WPBakeryShortCode_offshore_counter extends WPBakeryShortCode {
        }
    }
}
add_action( 'plugins_loaded', 'offshore_counter_box_parent_child' );