<?php

class Offshore_Downloads_Box {

    function __construct() {

        add_shortcode( 'offshore_downloads_box', array( $this, 'parent' ) );
        add_shortcode( 'offshore_downloads_box_item', array( $this, 'child' ) );
        if( has_action( 'vc_before_init' ) ){
            add_action( 'vc_before_init', array( $this, 'vc_parent' ) );
            add_action( 'vc_before_init', array( $this, 'vc_child' ) );
        }

    }

    function parent( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(

                'title' => '',
                'button_icon' => '',
                'button_text' => __( 'Download', 'offshorecore' ),
                'button_file' => '',
                'button_file_id' => '',
                'sub_title' => '',

            ), $atts));

        $button_file_size = '';
        if( class_exists( 'Offshore_Download_Widget' ) ) {
            $file = new Offshore_Download_Widget();
            $file_abs_url = get_attached_file( $button_file_id );
            // $file_name = basename( $file_abs_url );
            $button_file_size = '<span>' . $file->format( filesize( $file_abs_url ) ) . '</span>';
        }

        if( $title != '' ) {
            $title = '<h2 class="publish">' . $title . '</h2>';
        }

        $button = '';
        if( $button_file_id != '' ) {
            $button = '<div class="download-file">
                        <a href="' . site_url('?offshore_dl=') . esc_attr( $button_file_id ).'" class="offshore-download"><i class="fa '. $button_icon .'" style="margin-right:5px;" aria-hidden="true"></i>'. $button_text . $button_file_size .'</a>
                    </div>';
        }

        if( $sub_title != '' ) {
            $sub_title = '<li class="download-subtitle"><p>' . $sub_title . '</p></li>';
        }

        $output = '<div class="publication-downloads">
                    ' .  $title . $button . '
                    <ul class="download-list list-unstyled">
                        ' . $sub_title . do_shortcode( $content ) . '
                    </ul>
                </div>';

        $output = preg_replace('~<br />~', '', $output); // Remove <br> tags

        return $output;
    }

    function child( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(
                
                'file_name' => '',
                'file_id' => '',

            ), $atts));

        $file_size = '';

        if( class_exists( 'Offshore_Download_Widget' ) ) {
            $file = new Offshore_Download_Widget();
            $file_abs_url = get_attached_file( $file_id );
            // $file_name = basename( $file_abs_url );
            $file_size = '<span>' . $file->format( filesize( $file_abs_url ) ) . '</span>';
        }

        $output = '<li><a href="' . site_url('?offshore_dl=') . esc_attr( $file_id ) .'">' . $file_name . '</a>' . $file_size . '</li>';

        return $output;
    }

    function vc_parent() {
        vc_map( array(
            'name'        => __( 'Downloads Box', 'offshorecore' ),
            'description' => __( 'Adds a download box', 'offshorecore' ),
            'base'        => 'offshore_downloads_box',
            'class'       => 'offshore',
            'icon'        => 'fa fa-download',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'show_settings_on_create' => true,
            'as_parent'       => array( 'only' => 'offshore_downloads_box_item' ),
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Box Title', 'offshorecore' ),
                    'param_name'  => 'title',
                    'description' => __( 'Insert the title.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Button Text', 'offshorecore' ),
                    'param_name'  => 'button_text',
                    'description' => __( 'Insert text for button.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type' => 'iconpicker',
                    'admin_label' => true,
                    'heading' => __( 'Button Icon', 'offshorecore' ),
                    'param_name' => 'icon',
                    'value' => 'fa fa-pdf-o', // default value to backend editor admin_label
                    'settings' => array(
                        'emptyIcon' => true,
                        'iconsPerPage' => 4000
                    ),
                    'description' => __( 'Select the required icon.', 'offshorecore' ),
                ),
                array(
                    'type'        => 'attach_image',
                    'heading'     => __( 'Download File', 'offshorecore' ),
                    'param_name'  => 'button_file_id',
                    'description' => __( 'Select the file you want user to download on button click.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Box Sub Title', 'offshorecore' ),
                    'param_name'  => 'sub_title',
                    'description' => __( 'Insert text for sub title. Used for other downloads list.', 'offshorecore' ),
                    'value' => ''
                ),
            ),
            'js_view' => 'VcColumnView'
        ) );
    }

    function vc_child() {
        vc_map( array(
            'name'        => __( 'Downloads Box Item', 'offshorecore' ),
            'description' => __( 'Add download item', 'offshorecore' ),
            'base'        => 'offshore_downloads_box_item',
            'class'       => 'offshore',
            'icon'        => 'fa fa-download',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'as_child'       => array( 'only' => 'offshore_downloads_box' ),
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'List Item Name', 'offshorecore' ),
                    'param_name'  => 'file_name',
                    'description' => __( 'Insert item name ( other download item ).', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'attach_image',
                    'heading'     => __( 'List Item File', 'offshorecore' ),
                    'param_name'  => 'file_id',
                    'description' => __( 'Select the downloadable file.', 'offshorecore' ),
                    'value' => ''
                ),
            )
        ) );
    }

}

new Offshore_Downloads_Box();

function offshore_downloads_box_parent_child() {
    if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
        class WPBakeryShortCode_offshore_downloads_box extends WPBakeryShortCodesContainer {
        }
    }
    if ( class_exists( 'WPBakeryShortCode' ) ) {
        class WPBakeryShortCode_offshore_downloads_box_item extends WPBakeryShortCode {
        }
    }
}
add_action( 'plugins_loaded', 'offshore_downloads_box_parent_child' );