<?php

class Offshore_Google_Maps {

    private $maps = array();

    function __construct() {

        add_shortcode( 'offshore_google_maps', array( $this, 'parent' ) );
        add_shortcode( 'offshore_google_map', array( $this, 'child' ) );
        if( has_action( 'vc_before_init' ) ){
            add_action( 'vc_before_init', array( $this, 'vc_parent' ) );
            add_action( 'vc_before_init', array( $this, 'vc_child' ) );
        }

    }

    function parent( $atts, $content = '' ) {

        $output = '<div class="contact-map"><ul class="nav nav-pills" id="map-address">';

        $output .= do_shortcode( $content );

        $output .= '</ul>
                    <div id="google-map" class="google-map" data-latitude="' . $this->maps[0]['latitude'] . '" data-longitude="' . $this->maps[0]['longitude'] . '" data-map-title="' . $this->maps[0]['title'] . '" data-map-zoom="' . $this->maps[0]['zoom'] . '">
                    </div>
                </div>';

        $output = preg_replace('~<br />~', '', $output); // Remove <br> tags

        return $output;
    }

    function child( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(

                'latitude' => '',
                'longitude' => '',
                'title' => '',
                'zoom' => '',
                'active' => ''

            ), $atts));

        if( $active == 'yes' ) {
            $active = 'active';
        } else {
            $active = '';
        }

        $output = sprintf( '<li class="%1$s"><a href="#" data-latitude="%2$s" data-longitude="%3$s" data-map-title="%4$s" data-map-zoom="%5$s" data-toggle="tab">%4$s</a></li>', $active, esc_attr( $latitude ), esc_attr( $longitude ), esc_attr( $title ), esc_attr( $zoom ) );

        $this->maps[] = array( 'latitude' => esc_attr( $latitude ),
                'longitude' => esc_attr( $longitude ),
                'title' => esc_attr( $title ),
                'zoom' => esc_attr( $zoom )
            );

        return $output;
    }

    function vc_parent() {
        vc_map( array(
            'name'        => __( 'Google Maps', 'offshorecore' ),
            'description' => __( 'Add tabbed Google maps.', 'offshorecore' ),
            'base'        => 'offshore_google_maps',
            'class'       => 'offshore',
            'icon'        => 'fa fa-globe',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'show_settings_on_create' => false,
            'is_container' => true,
            'as_parent'       => array( 'only' => 'offshore_google_map' ),
            'params'      => array(
            ),
            'js_view' => 'VcColumnView'
        ) );
    }

    function vc_child() {
        vc_map( array(
            'name'        => __( 'Map Tab', 'offshorecore' ),
            'description' => __( 'Add a map tab', 'offshorecore' ),
            'base'        => 'offshore_google_map',
            'class'       => 'offshore',
            'icon'        => 'fa fa-globe',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'as_child'       => array( 'only' => 'offshore_google_maps' ),
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'heading'     => __( 'Map Latitude', 'offshorecore' ),
                    'admin_label' => true,
                    'param_name'  => 'latitude',
                    'description' => __( 'Insert the latitude. You can use http://www.mapcoordinates.net/ to get latitude value.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Map Longitude', 'offshorecore' ),
                    'param_name'  => 'longitude',
                    'description' => __( 'Insert the longitude. You can use http://www.mapcoordinates.net/ to get longitude value.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'dropdown',
                    'admin_label' => true,
                    'heading'     => __( 'Map Zoom Level', 'offshorecore' ),
                    'param_name'  => 'zoom',
                    'value'       => array(
                        '0' => '0',
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '5' => '5',
                        '6' => '6',
                        '7' => '7',
                        '8' => '8',
                        '9' => '9',
                        '10' => '10',
                        '11' => '11',
                        '12' => '12',
                        '13' => '13',
                        '14' => '14',
                        '15' => '15',
                        '16' => '16',
                        '17' => '17',
                        '18' => '18',
                        '19' => '19'
                    ),
                    'description' => __( 'Insert the longitude. You can use http://www.mapcoordinates.net/ to get longitude value.', 'offshorecore' )
                ),
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'heading'     => __( 'Map title', 'offshorecore' ),
                    'param_name'  => 'title',
                    'description' => __( 'Insert the title. Eg. United Kingdom.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'dropdown',
                    'admin_label' => true,
                    'heading'     => __( 'Map Tab Active', 'offshorecore' ),
                    'param_name'  => 'active',
                    'value'       => array(
                        __( 'No', 'offshorecore' ) => 'no',
                        __( 'Yes', 'offshorecore' ) => 'yes'
                    ),
                    'description' => __( 'Make this tab active by default.', 'offshorecore' )
                )
            )
        ) );
    }

}

new Offshore_Google_Maps();

function offshore_google_maps_parent_child() {
    if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
        class WPBakeryShortCode_offshore_google_maps extends WPBakeryShortCodesContainer {
        }
    }
    if ( class_exists( 'WPBakeryShortCode' ) ) {
        class WPBakeryShortCode_offshore_google_map extends WPBakeryShortCode {
        }
    }
}
add_action( 'plugins_loaded', 'offshore_google_maps_parent_child' );