<?php

class Offshore_Tab {

    private $tab_counter = 1;
    private $panel_counter = 1;
    private $tab_nav = array();

    function __construct() {

        add_shortcode( 'offshore_tab', array( $this, 'parent' ) );
        add_shortcode( 'offshore_tab_panel', array( $this, 'child' ) );
        if( has_action( 'vc_before_init' ) ){
            add_action( 'vc_before_init', array( $this, 'vc_parent' ) );
            add_action( 'vc_before_init', array( $this, 'vc_child' ) );
        }

    }

    function parent( $atts, $content = '' ) {

        $id = sprintf( 'tab-%s-%s', get_the_ID(), $this->tab_counter );

        $output = '<div class="tab-widget"><ul id="' . $id . '" class="nav nav-tabs" role="tablist">';

        $content = do_shortcode( $content );

        // var_dump( $this->tab_nav );

        foreach ( $this->tab_nav as $key => $value) {
            if( $value['open'] == 'yes' ){
                $class = 'active';
                $expanded = ' aria-expanded="true"';
            } else {
                $class = '';
                $expanded = '';
            }
            $output .= sprintf( '<li role="presentation" class="%1$s"><a href="#%2$s" id="%2$s-tab" role="tab" data-toggle="tab" aria-controls="%2$s">%4$s</a></li>', $class, $value['id'], $expanded, $value['title'] );
        }

        $output .= '</ul><div id="' . $id . '-content" class="tab-content">' . $content . '</div></div>';

        $output = preg_replace('~<br />~', '', $output); // Remove <br> tags

        $this->tab_counter++;

        return $output;
    }

    function child( $atts, $content = '' ) {

        extract( shortcode_atts(

            array(
                'title' => '',
                'open' => 'no'

            ), $atts));

        if( $open == 'yes' ){
            $class = ' in active';
        }else{
            $class = '';
        }

        $id = substr( md5( sprintf( 'tabpanel-%s-%s-%s', get_the_ID(), $this->tab_counter, $this->panel_counter ) ), 15 );

        $output = sprintf( '<div role="tabpanel" class="tab-pane fade%2$s" id="%1$s" aria-labelledBy="%1$s-tab">%3$s</div>', $id, $class, wpautop( do_shortcode( $content ) ) );

        $this->tab_nav[] = array( 'id' => $id, 'title' => $title, 'open' => $open );

        $this->panel_counter++;

        return $output;
    }

    function vc_parent() {
        vc_map( array(
            'name'        => __( 'Tabs', 'offshorecore' ),
            'description' => __( 'Add tabs.', 'offshorecore' ),
            'base'        => 'offshore_tab',
            'class'       => 'offshore',
            'icon'        => 'fa fa-folder',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'show_settings_on_create' => false,
            'is_container' => true,
            'as_parent'       => array( 'only' => 'offshore_tab_panel' ),
            'params'      => array(
            ),
            'js_view' => 'VcColumnView'
        ) );
    }

    function vc_child() {
        vc_map( array(
            'name'        => __( 'Tab Panel', 'offshorecore' ),
            'description' => __( 'Add a panel.', 'offshorecore' ),
            'base'        => 'offshore_tab_panel',
            'class'       => 'offshore',
            'icon'        => 'fa fa-folder',
            'category'    => __( 'Offshore', 'offshorecore' ),
            'content_element' => true,
            'as_child'       => array( 'only' => 'offshore_tab' ),
            'params'      => array(
                array(
                    'type'        => 'textfield',
                    'admin_label' => true,
                    'class'       => '',
                    'heading'     => __( 'Title', 'offshorecore' ),
                    'param_name'  => 'title',
                    'description' => __( 'Insert tab panel title.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'textarea_html',
                    'class'       => '',
                    'heading'     => __( 'Tab Panel Content', 'offshorecore' ),
                    'param_name'  => 'content',
                    'description' => __( 'Insert tab panel content.', 'offshorecore' ),
                    'value' => ''
                ),
                array(
                    'type'        => 'dropdown',
                    'class'       => '',
                    'heading'     => __( 'Open by default', 'offshorecore' ),
                    'param_name'  => 'open',
                    'value'       => array(
                        __( 'No', 'offshorecore' ) => 'no',
                        __( 'Yes', 'offshorecore' ) => 'yes'
                    ),
                    'description' => __( 'Keep this panel open by default.', 'offshorecore' )
                )
            )
        ) );
    }

}

new Offshore_Tab();

function offshore_tab_parent_child() {
    if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
        class WPBakeryShortCode_offshore_tab extends WPBakeryShortCodesContainer {
        }
    }
    if ( class_exists( 'WPBakeryShortCode' ) ) {
        class WPBakeryShortCode_offshore_tab_panel extends WPBakeryShortCode {
        }
    }
}
add_action( 'plugins_loaded', 'offshore_tab_parent_child' );