<?php

/**
 * Inline Stock Quotes
 * @since  1.0.0
 * @param  array    $atts
 * @return string
 */
function offshore_stock( $atts ) {
    //make array of arguments and give these arguments to the shortcode
    $a = shortcode_atts( array(
        'symbol' => '',
        // 'service' => 'google'
    ), $atts );

    //create variables from arguments array
    extract( $a );

    require_once( ABSPATH . 'wp-admin/includes/file.php' );
    $access_type = get_filesystem_method();

    if( $access_type === 'direct') {
        /* you can safely run request_filesystem_credentials() without any issues and don't need to worry about passing in a URL */
        $creds = request_filesystem_credentials(site_url() . '/wp-admin/', '', false, false, array());

        /* initialize the API */
        if ( ! WP_Filesystem($creds) ) {
            /* any problems and we exit */
            return false;
        }   

        global $wp_filesystem;
        /* do our file manipulations below */
        // get the string from google
        $quote = $wp_filesystem->get_contents( 'http://finance.google.com/finance/info?client=ig&q='. "{$symbol}" );

    } else {

        /* don't have direct write access. Prompt user with our notice */
        add_action('admin_notices', 'offshore_stock_notice');

    }

    if( $quote ) {
    
        //remove carriage returns from the string
        $quote = str_replace("\n", "", $quote);
        
        //remove random junk from front and end of string
        $quote = substr($quote, 4, -1);
        
        //turn json string into php variables
        $quote = json_decode( utf8_decode( $quote ) );
        
        //get latest price
        $last = $quote->l;
        
        //get dollar change
        $change_dollar = $quote->c;
        
        //build the css style strings
        // $service = $service;
        // $google_quote_url = 'https://www.google.com/finance?q='."{$symbol}";
        // $yahoo_quote_url = 'http://finance.yahoo.com/q?s='."{$symbol}";

        // get percent change
        // $change_price = $quote->cp;

        //check if positive, negative, or neutral, then assign color via options
        if ( strstr($change_dollar, '+')) {
            $icon = 'fa-caret-up';
        } elseif ( strstr($change_dollar, '-')) {
            $icon = 'fa-caret-down';
        } else {
            $icon = '';
        }

         //check which service was selected for quotes
         // if ( $service == 0 ) {
         //    $service = $google_quote_url;
         //        } else {
         //    $service = $yahoo_quote_url;
         // }


        //make main span
        $output = '<p>' . $last . '<span class="forex"> <i class="fa ' . $icon . '" aria-hidden="true"></i> ' . $change_dollar . ' </span></p>';
        

        //return completed string
        return $output;

    } else {

        return '<p>' . __( 'Symbol not found.', 'offshore' ) . '</p>';

    }
}

function offshore_stock_notice() {
?>
    <div class="notice notice-success is-dismissible">
        <p><?php _e( 'WordPress fielsystem error. Unable to read stock data.', 'offshore' ); ?></p>
    </div>
<?php
}

/**
 * Adds Offshore_Stock_Widget widget.
 */
class Offshore_Stock_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_stock_widget', // Base ID
            __( 'Offshore Stock', 'offshore' ), // Name
            array( 
                'description' => __( 'Displays stock price', 'offshore' )
            ) // Args
        );
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $title = '';
        if( isset( $instance['title'] ) ) {
            $title = $instance['title'];
        }
        $stock = '';
        if( isset( $instance['stock'] ) ) {
            $stock = $instance['stock'];
        }
        // $service = 'google';
        // if( isset( $instance['service'] ) ) {
        //     $service = $instance['service'];
        // }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'stock' ) ); ?>"><?php _e( 'Stock:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'stock' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'stock' ) ); ?>" type="text" value="<?php echo esc_attr( $stock ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['stock'] = ( ! empty( $new_instance['stock'] ) ) ? sanitize_text_field( $new_instance['stock'] ) : '';
        // $instance['service'] = ( ! empty( $new_instance['service'] ) ) ? sanitize_text_field( $new_instance['service'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['title'] ) ) {
            echo '<h3>' . $instance['title'] . '</h3>';            
        }
        if ( ! empty( $instance['stock'] ) ) {
            echo '<div class="textwidget">';
            echo offshore_stock( array( 'symbol' => $instance['stock'], 'service' => $instance['service'] ) );
            echo '</div>';
        }
        echo $args['after_widget'];
    }

} // class Offshore_Stock_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_Stock_Widget");' ) );

add_filter( 'stag_custom_sidebars_widget_args', 'offshore_sidebar_args' );
function offshore_sidebar_args( $args ) {
    return $args = array(
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="sidebar-title">',
        'after_title'   => '</h3>',
    );
}