<?php 


class OffshoreFormElements {

    private static $instance;

    /**
     * Initiator
     * @since 0.1
     */
    public static function init(){
        return self::$instance;
    }

    /**
     * Generate input HTML
     * @since  1.0.0
     * @param  array     $args  existing options array
     * @return array    all standard DOM input options
     */
    public function input( $args = array() ) {

        $defaults = array(
            'type'              =>  'text',
            'cpt'               =>  'post',
            'id'                =>  NULL,
            'name'              =>  NULL,
            'class'             =>  NULL,
            'multiselect'       =>  NULL,
            'title'             =>  NULL,
            'placeholder'       =>  NULL,
            'label'             =>  NULL,
            'description'       =>  NULL,
            'min'               =>  0,
            'max'               =>  100,
            'on_text'           =>  esc_html__( 'On', 'offshore' ),
            'off_text'          =>  esc_html__( 'Off', 'offshore' ),
            'step'              =>  1,
            'value'             =>  NULL,
            'options'           =>  array()
        );

        // Merge arguments together 
        $input = wp_parse_args( $args, $defaults );
        $no_esc_key = array( 'cpt', 'options', 'tooltip', 'value', 'multiselect', 'copy_ids', 'copy_text', 'copy_ids' );

        // Validate the data - All input values are validated here with few exceptions, exceptions are validated on occurence
        foreach ( $input as $k => $v ) {
            if( !in_array( $k, $no_esc_key ) ) {
                $input[$k] = esc_attr( $v );
            }
        }

        // Create input attributes
        $input_props = array();
        $input_props['id'] = ( $input['id'] != NULL ) ? 'id="' . $input['id'] . '"' : NULL;
        $input_props['name'] = ( $input['name'] != NULL ) ? 'name="' . $input['name'] . '"' : NULL;
        $input_props['placeholder'] = ( $input['placeholder'] != NULL ) ? 'placeholder="' . $input['placeholder'] . '"' : NULL;
        // $input_props['class'] = ( $input['class'] != NULL ) ? 'class="' . $input['class'] . '"' : NULL;
        $input_props['value'] = ( $input['value'] != NULL && !is_array( $input['value'] ) ) ? 'value="' . esc_attr( $input['value'] ) . '"' : NULL;

        // declare allowed html tags for select options
        $select_allowed_html = array(
            'optgroup' => array(
                'label' => array()
            ),
            'option' => array(
                'value' => array(),
                'selected' => array()
            )
        );

        switch ( $input['type'] ) {

            case 'text': 

            ?>
                <div class="offshore-section offshore-group">
                    <div class="offshore-col offshore-span_4_of_12">
                        <p class="label"><?php echo esc_html( $input['label'] ); ?></p>
                        <em><?php echo esc_html( $input['description'] ); ?></em>
                    </div>
                    <div class="offshore-col offshore-span_8_of_12">
                        <input class="offshore-text" <?php echo esc_html( implode( ' ', $input_props ) ); ?> />
                    </div>
                </div>
                <?php break;

            case 'textarea': 

                unset( $input_props['value'] );

            ?>
                <div class="offshore-section offshore-group">
                    <div class="offshore-col offshore-span_4_of_12">
                        <p class="label"><?php echo esc_html( $input['label'] ); ?></p>
                        <em><?php echo esc_html( $input['description'] ); ?></em>
                    </div>
                    <div class="offshore-col offshore-span_8_of_12">
                        <textarea rows="5" cols="50" class="offshore-textarea" <?php echo esc_html( implode( ' ', $input_props ) ); ?>><?php echo esc_textarea( $input['value'] ); ?></textarea>
                    </div>
                </div>
                <?php break;

            case 'select': 

                    $input_props['select_placeholder'] = ( $input['placeholder'] != NULL ) ? $input['placeholder'] : 'placeholder="' . esc_html__('Choose your option','offshore') . '"';
                    $input['value'] = maybe_unserialize( $input['value'] );
                    $multi_select = ( isset( $input['multiselect'] ) && $input['multiselect'] === true ) ? ' multiple="multiple"' : '';

                    ?>
                    <div class="offshore-section offshore-group">
                        <div class="offshore-col offshore-span_4_of_12">
                            <p><?php echo esc_html( $input['label'] ); ?></p>
                            <em><?php echo esc_html( $input['description'] ); ?></em>
                        </div>
                        <div class="offshore-col offshore-span_8_of_12">
                            <div class="offshore-select-button offshore-core-select">
                                <select <?php echo implode( ' ', $input_props ); ?>>
                                    <?php 
                                        foreach ( $input['options'] as $key => $label ) {
                                            if( is_array( $input['value'] ) ) {
                                                if( in_array( $key, $input['value'] ) ) {
                                                    echo '<option value="' . esc_attr( $key ) . '" selected>' . sanitize_text_field( $label ) . '</option>';
                                                } else {
                                                    echo '<option value="' . esc_attr( $key ) . '">' . sanitize_text_field( $label ) . '</option>';
                                                }
                                            } else {
                                                if( $input['value'] == $key ){
                                                    echo '<option value="' . esc_attr( $key ) . '" selected>' . (string) $label . '</option>';
                                                } else {
                                                    echo '<option value="' . esc_attr( $key ) . '">' . (string) $label . '</option>';
                                                }
                                            }
                                        }
                                    ?>
                                </select>
                            </div>
                        </div>
                    </div>
                    <?php break;

            default: ?>
                <input type="hidden" <?php echo esc_html( implode( ' ', $input_props ) ); ?>>
                <?php break;
        
        }
    }

}