<?php

/**
 * Register our widgetized areas.
 * @since  1.0.0
 * @uses register_sidebar()
 */
function offshore_widgets_init() {

    register_sidebar( array(
        'name'          => esc_html__( 'Top Widgets', 'offshore' ),
        'id'            => 'offshore_top_widgets',
        'before_widget' => '<div class="widget">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Pre Footer Widgets', 'offshore' ),
        'id'            => 'offshore_pre_footer_widgets',
        'before_widget' => '<div class="widget '. offshore_count_widgets( 'offshore_pre_footer_widgets' ) .'">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="pre-footer-title">',
        'after_title'   => '</h4>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Widgets', 'offshore' ),
        'id'            => 'offshore_footer_widgets',
        'before_widget' => '<div class="widget '. offshore_count_widgets( 'offshore_footer_widgets' ) .' col-sm-6">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Bottom Left Widgets', 'offshore' ),
        'id'            => 'offshore_footer_bl_widgets',
        'before_widget' => '<div class="widget footer-widgets footer-bottom-widgets">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Bottom Right Widgets', 'offshore' ),
        'id'            => 'offshore_footer_br_widgets',
        'before_widget' => '<div class="widget footer-widgets footer-bottom-widgets">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

}
add_action( 'widgets_init', 'offshore_widgets_init' );

/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 * https://gist.github.com/slobodan/6156076
 */
function offshore_count_widgets( $sidebar_id ) {
    // If loading from front page, consult $_wp_sidebars_widgets rather than options
    // to see if wp_convert_widget_settings() has made manipulations in memory.
    global $_wp_sidebars_widgets;
    if ( empty( $_wp_sidebars_widgets ) ) {
        $_wp_sidebars_widgets = get_option( 'sidebars_widgets', array() );
    }
    
    $sidebars_widgets_count = $_wp_sidebars_widgets;
    
    if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) {
        $widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
        $widget_classes = 'widget-count-' . count( $sidebars_widgets_count[ $sidebar_id ] );
        if ( $widget_count == 1 ) {
            // if there is exactly one widget
            $widget_classes .= ' col-md-12';
        } elseif ( $widget_count == 2 ) {
            // if there are exactly two widgets
            $widget_classes .= ' col-md-6';
        } elseif ( $widget_count == 3 ) {
            // if there are exactly three widgets
            $widget_classes .= ' col-md-4';
        } elseif ( $widget_count == 4 ) {
            // if there are exactly four widgets 
            $widget_classes .= ' col-md-3';
        } elseif ( $widget_count == 6 ) {
            // if there are exactly six widgets
            $widget_classes .= ' col-md-2';
        }
        return $widget_classes;
    }
}

/**
 * Adds Offshore_Icons_Widget widget.
 */
class Offshore_Icons_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_icons_widget', // Base ID
            esc_html__( 'Offshore Icons', 'offshore' ), // Name
            array( 
                'description' => esc_html__( 'Displays social icons', 'offshore' )
            ) // Args
        );
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $title = '';
        if( isset( $instance['title'] ) ) {
            $title = $instance['title'];
        }
        $size = '';
        if( isset( $instance['size'] ) ) {
            $size = $instance['size'];
        }
        $facebook = '';
        if( isset( $instance['facebook'] ) ) {
            $facebook = $instance['facebook'];
        }
        $twitter = '';
        if( isset( $instance['twitter'] ) ) {
            $twitter = $instance['twitter'];
        }
        $google = '';
        if( isset( $instance['google'] ) ) {
            $google = $instance['google'];
        }
        $linkedin = '';
        if( isset( $instance['linkedin'] ) ) {
            $linkedin = $instance['linkedin'];
        }
        $instagram = '';
        if( isset( $instance['instagram'] ) ) {
            $instagram = $instance['instagram'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>"><?php esc_html_e( 'Icon Size:', 'offshore' ); ?></label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'size' ) ); ?>"  name="<?php echo esc_attr( $this->get_field_name( 'size' ) ); ?>" class="">
                <option value="normal" 
                    <?php if( isset( $size ) && $size == 'normal' ) {
                        echo 'selected';
                    } ?>
                ><?php esc_html_e( 'normal', 'offshore' ) ?></option>
                <option value="large" 
                    <?php if( isset( $size ) && $size == 'large' ) {
                        echo 'selected';
                    } ?>
                ><?php esc_html_e( 'large', 'offshore' ) ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'facebook' ) ); ?>"><?php esc_html_e( 'Facebook Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'facebook' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'facebook' ) ); ?>" type="text" value="<?php echo esc_url( $facebook ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'twitter' ) ); ?>"><?php esc_html_e( 'Twitter Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'twitter' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'twitter' ) ); ?>" type="text" value="<?php echo esc_url( $twitter ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'google' ) ); ?>"><?php esc_html_e( 'Google+ Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'google' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'google' ) ); ?>" type="text" value="<?php echo esc_url( $google ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'linkedin' ) ); ?>"><?php esc_html_e( 'LinkedIn Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'linkedin' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'linkedin' ) ); ?>" type="text" value="<?php echo esc_url( $linkedin ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'instagram' ) ); ?>"><?php esc_html_e( 'Instagram Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'instagram' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'instagram' ) ); ?>" type="text" value="<?php echo esc_url( $instagram ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['size'] = ( ! empty( $new_instance['size'] ) ) ? esc_textarea( $new_instance['size'] ) : '';
        $instance['facebook'] = ( ! empty( $new_instance['facebook'] ) ) ? esc_url( $new_instance['facebook'] ) : '';
        $instance['twitter'] = ( ! empty( $new_instance['twitter'] ) ) ? esc_url( $new_instance['twitter'] ) : '';
        $instance['google'] = ( ! empty( $new_instance['google'] ) ) ? esc_url( $new_instance['google'] ) : '';
        $instance['linkedin'] = ( ! empty( $new_instance['linkedin'] ) ) ? esc_url( $new_instance['linkedin'] ) : '';
        $instance['instagram'] = ( ! empty( $new_instance['instagram'] ) ) ? esc_url( $new_instance['instagram'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['size'] ) ) {
            echo '<div class="social">';
            if( isset( $instance['title'] ) && $instance['title'] ) {
                echo '<h3>' . esc_attr( $instance['title'] ) . '</h3>';
            }
            if( $instance['size'] == 'large' ) {
                ?>
                    <ul class="social-icons">
                        <?php 
                            if( isset( $instance['facebook'] ) && $instance['facebook'] ) {
                                echo '<li><a href="'. $instance['facebook'] .'"><i class="fa fa-facebook" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['twitter'] ) && $instance['twitter'] ) {
                                echo '<li><a href="'. $instance['twitter'] .'"><i class="fa fa-twitter" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['google'] ) && $instance['google'] ) {
                                echo '<li><a href="'. $instance['google'] .'"><i class="fa fa-google-plus" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['linkedin'] ) && $instance['linkedin'] ) {
                                echo '<li><a href="'. $instance['linkedin'] .'"><i class="fa fa-linkedin" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['instagram'] ) && $instance['instagram'] ) {
                                echo '<li><a href="'. $instance['instagram'] .'"><i class="fa fa-instagram" aria-hidden="true"></i></a></li>';
                            }
                        ?>
                    </ul>
                <?php
            } else {
                ?>
                    <ul class="widgets-social">
                        <?php 
                            if( isset( $instance['facebook'] ) && $instance['facebook'] ) {
                                echo '<li><a href="'. $instance['facebook'] .'"><i class="fa fa-facebook" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['twitter'] ) && $instance['twitter'] ) {
                                echo '<li><a href="'. $instance['twitter'] .'"><i class="fa fa-twitter" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['google'] ) && $instance['google'] ) {
                                echo '<li><a href="'. $instance['google'] .'"><i class="fa fa-google-plus" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['linkedin'] ) && $instance['linkedin'] ) {
                                echo '<li><a href="'. $instance['linkedin'] .'"><i class="fa fa-linkedin" aria-hidden="true"></i></a></li>';
                            }
                            if( isset( $instance['instagram'] ) && $instance['instagram'] ) {
                                echo '<li><a href="'. $instance['instagram'] .'"><i class="fa fa-instagram" aria-hidden="true"></i></a></li>';
                            }
                        ?>
                    </ul>
                <?php
            }
            echo '</div>';
        }
        echo $args['after_widget'];
    }

} // class Offshore_Call_To_Action_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_Icons_Widget");' ) );

/**
 * Adds Offshore_Download_Widget widget.
 */
class Offshore_Download_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_download_widget', // Base ID
            esc_html__( 'Offshore Download Button', 'offshore' ), // Name
            array( 
                'class' => 'offshore_media_upload',
                'description' => esc_html__( 'Displays a download button', 'offshore' )
            ) // Args
        );
        add_action( 'admin_enqueue_scripts', array( $this, 'upload_scripts' ) );
        add_action( 'admin_footer', array( $this, 'custom_script' ) );
    }

    /**
     * Upload the Javascripts for the media uploader
     */
    public function upload_scripts() {
        wp_enqueue_media();
        wp_enqueue_style( 'fontawesome', OFFSHORE_CSS_URL . '/font-awesome.min.css', false, '4.5.0' );
        wp_enqueue_style( 'selectize', OFFSHORE_CSS_URL . '/selectize.css', false, '0.12.1' );
        wp_enqueue_script( 'selectize', OFFSHORE_JS_URL . '/selectize.min.js', array( 'jquery' ), '0.12.1', false );
    }

    public function custom_script() { ?>
        <script type="text/javascript">
            jQuery(document).ready(function($){
                jQuery(document).on('click','.widget-title,.widget-title-action,.widget-control-save', function(){
                    var select = jQuery(this).parent().next().find('.offshore-select');
                    if( !select.hasClass('selectized') ){
                        select.selectize({
                            options: [
                                {id: 'fa-file'},
                                {id: 'fa-file-archive-o'},
                                {id: 'fa-file-audio-o'},
                                {id: 'fa-file-code-o'},
                                {id: 'fa-file-excel-o'},
                                // {id: 'fa-file-image-o'},
                                {id: 'fa-file-movie-o'},
                                {id: 'fa-file-o'},
                                {id: 'fa-file-pdf-o'},
                                {id: 'fa-file-photo-o'},
                                // {id: 'fa-file-picture-o'},
                                {id: 'fa-file-powerpoint-o'},
                                {id: 'fa-file-sound-o'},
                                {id: 'fa-file-text'},
                                {id: 'fa-file-text-o'},
                                {id: 'fa-file-video-o'},
                                {id: 'fa-file-word-o'},
                                {id: 'fa-file-zip-o'},
                            ],
                            create: false,
                            valueField: 'id',
                            labelField: 'id',
                            searchField: 'id',
                            sortField: 'text',
                            render: {
                                option: function(item, escape) {
                                    return '<span style="">' +
                                        '<i id="'+ item.id +'" class="fa '+ item.id +'" title="'+ item.id +'" style="font-size:32px;width:30px!important;height:50px!important;"></i>' +
                                    '</span>';
                                }
                            }
                        });
                    };
                });
                jQuery(document).on('click','.widget-control-save', function(){
                    $(this).ajaxComplete(function(event, XMLHttpRequest, ajaxOptions) {
                        var select = jQuery(this).parent().parent().parent().find('.offshore-select');
                        if( !select.hasClass('selectized') ){
                            select.selectize({
                                options: [
                                    {id: 'fa-file'},
                                    {id: 'fa-file-archive-o'},
                                    {id: 'fa-file-audio-o'},
                                    {id: 'fa-file-code-o'},
                                    {id: 'fa-file-excel-o'},
                                    // {id: 'fa-file-image-o'},
                                    {id: 'fa-file-movie-o'},
                                    {id: 'fa-file-o'},
                                    {id: 'fa-file-pdf-o'},
                                    {id: 'fa-file-photo-o'},
                                    // {id: 'fa-file-picture-o'},
                                    {id: 'fa-file-powerpoint-o'},
                                    {id: 'fa-file-sound-o'},
                                    {id: 'fa-file-text'},
                                    {id: 'fa-file-text-o'},
                                    {id: 'fa-file-video-o'},
                                    {id: 'fa-file-word-o'},
                                    {id: 'fa-file-zip-o'},
                                ],
                                create: false,
                                valueField: 'id',
                                labelField: 'id',
                                searchField: 'id',
                                sortField: 'text',
                                render: {
                                    option: function(item, escape) {
                                        return '<span style="">' +
                                            '<i id="'+ item.id +'" class="fa '+ item.id +'" title="'+ item.id +'" style="font-size:32px;width:30px!important;height:50px!important;"></i>' +
                                        '</span>';
                                    }
                                }
                            });
                        };
                    });
                });
                $('#widgets-right').on( 'click', '.offshore_upload_btn', function(e) {
                    var $this = $(this);
                    var image = wp.media({ 
                        title: '<?php esc_html_e( "Upload Image", "offshore" ); ?>',
                        // mutiple: true if you want to upload multiple files at once
                        multiple: false
                    }).open()
                    .on('select', function(e){
                        // This will return the selected image from the Media Uploader, the result is an object
                        var uploaded_image = image.state().get('selection').first();
                        // We convert uploaded_image to a JSON object to make accessing it easier
                        // Output to the console uploaded_image
                        console.log(uploaded_image.toJSON());
                        var json = uploaded_image.toJSON();
                        var image_url = json.url;
                        var image_id = json.id;
                        // Let's assign the url value to the input field
                        $this.prev('.offshore-file-url').val(image_url);
                        $this.next('.offshore-file-id').val(image_id);
                    });
                });
            });
        </script>
    <?php }


    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $icon = '';
        if( isset( $instance['icon'] ) ) {
            $icon = $instance['icon'];
        }
        $text = esc_html__( 'Download', 'offshore' );
        if( isset( $instance['text'] ) ) {
            $text = $instance['text'];
        }
        $file = '';
        if( isset( $instance['file'] ) ) {
            $file = $instance['file'];
        }
        $file_id = '';
        if( isset( $instance['file_id'] ) ) {
            $file_id = $instance['file_id'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'icon' ) ); ?>"><?php esc_html_e( 'Button Icon:', 'offshore' ); ?></label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'icon' ) ); ?>"  name="<?php echo esc_attr( $this->get_field_name( 'icon' ) ); ?>" class="offshore-select">
                <option value="<?php echo esc_attr( $icon ); ?>"><?php echo esc_html( $icon ); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'text' ) ); ?>" type="text" value="<?php echo esc_attr( $text ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'file' ) ); ?>"><?php esc_html_e( 'Download File:', 'offshore' ); ?></label>
            <input class="widefat offshore-file-url" id="<?php echo esc_attr( $this->get_field_id( 'file' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'file' ) ); ?>" type="text" value="<?php echo esc_url( $file ); ?>">
            <input id="offshore_upload_btn" class="offshore_upload_btn button button-secondary" type="button" value="<?php esc_html_e( 'Upload File', 'offshore' ); ?>" />
            <input class="widefat offshore-file-id" id="<?php echo esc_attr( $this->get_field_id( 'file_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'file_id' ) ); ?>" type="hidden" value="<?php echo esc_attr( $file_id ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['icon'] = ( ! empty( $new_instance['icon'] ) ) ? sanitize_text_field( $new_instance['icon'] ) : '';
        $instance['text'] = ( ! empty( $new_instance['text'] ) ) ? sanitize_text_field( $new_instance['text'] ) : '';
        $instance['file'] = ( ! empty( $new_instance['file'] ) ) ? esc_url( $new_instance['file'] ) : '';
        $instance['file_id'] = ( ! empty( $new_instance['file_id'] ) ) ? sanitize_text_field( $new_instance['file_id'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['text'] ) ) {
            $text = $instance['text'];
            $file_abs_url = get_attached_file( $instance['file_id'] );
            $file_name = basename( $file_abs_url );
            $file_size = $this->format( filesize( $file_abs_url ) );
            ?>
                <div class="sidebar-download">
                    <div class="download-file color-bg">
                        <a href="<?php echo site_url('?offshore_dl=') . esc_attr( $instance['file_id'] ); ?>"  download="<?php echo esc_attr( $file_name ); ?>"><i class="fa <?php echo esc_attr( $instance['icon'] ); ?>" aria-hidden="true"></i> <?php echo esc_html( $text ); ?><span><?php echo esc_html( $file_size ); ?></span>
                        </a>
                    </div>
                </div>
            <?php
        }
        echo $args['after_widget'];
    }

    /**
     * Converts bytes into GB, MB, KB, bytes, byte.
     * http://stackoverflow.com/questions/5501427/php-filesize-mb-kb-conversion
     * 
     * @since  1.0.0
     * @param  int    $bytes
     * @return string
     */
    public function format( $bytes ) {
        if ($bytes >= 1073741824) {
            $bytes = number_format($bytes / 1073741824, 2) . ' ' . esc_html__( 'GB', 'offshore' );
        } elseif ($bytes >= 1048576) {
            $bytes = number_format($bytes / 1048576, 2) . ' ' . esc_html__( 'MB', 'offshore' );
        } elseif ($bytes >= 1024) {
            $bytes = number_format($bytes / 1024, 2) . ' ' . esc_html__( 'KB', 'offshore' );
        } elseif ($bytes > 1) {
            $bytes = $bytes . ' ' . esc_html__( 'bytes', 'offshore' );
        } elseif ($bytes == 1) {
            $bytes = $bytes . ' ' . esc_html__( 'byte', 'offshore' );
        } else {
            $bytes = esc_html__( '0 bytes', 'offshore' );
        }
        return $bytes;
    }

} // class Offshore_Download_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_Download_Widget");' ) );

/**
 * Adds Offshore_CTA_Widget widget.
 */
class Offshore_CTA_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_cta_widget', // Base ID
            esc_html__( 'Offshore Call To Action', 'offshore' ), // Name
            array( 
                'description' => esc_html__( 'Displays a call to action widget', 'offshore' )
            ) // Args
        );
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $title = esc_html__( 'Quick Fact', 'offshore' );
        if( isset( $instance['title'] ) ) {
            $title = $instance['title'];
        }
        $description = '';
        if( isset( $instance['description'] ) ) {
            $description = $instance['description'];
        }
        $button_text = '';
        if( isset( $instance['button_text'] ) ) {
            $button_text = $instance['button_text'];
        }
        $button_url = '';
        if( isset( $instance['button_url'] ) ) {
            $button_url = $instance['button_url'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>"><?php esc_html_e( 'Description:', 'offshore' ); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>" ><?php echo esc_textarea( $description ); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>"><?php esc_html_e( 'Button Link:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'button_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_url' ) ); ?>" type="text" value="<?php echo esc_attr( $button_url ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['description'] = ( ! empty( $new_instance['description'] ) ) ? wp_kses_post( $new_instance['description'] ) : '';
        $instance['button_text'] = ( ! empty( $new_instance['button_text'] ) ) ? sanitize_text_field( $new_instance['button_text'] ) : '';
        $instance['button_url'] = ( ! empty( $new_instance['button_url'] ) ) ? esc_url( $new_instance['button_url'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['title'] ) ) {
            ?>
                <div class="sidebar-fact">
                    <h3 class="about-quick-fact"><?php echo esc_html( $instance['title'] ); ?></h3>
                    <p><?php echo esc_html( $instance['description'] ); ?></p>
                    <a href="<?php echo esc_url( $instance['button_url'] ); ?>" class="btn btn-primary about-quick-fact-button" role="button"><?php echo esc_html( $instance['button_text'] ); ?></a>
                </div>
            <?php
        }
        echo $args['after_widget'];
    }

} // class Offshore_Call_To_Action_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_CTA_Widget");' ) );

/**
 * Adds Offshore_Contact_Box_Widget widget.
 */
class Offshore_Contact_Box_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_contact_box_widget', // Base ID
            esc_html__( 'Offshore Contact Box', 'offshore' ), // Name
            array( 
                'class' => 'offshore_contact_box',
                'description' => esc_html__( 'Displays a rectangular contact box.', 'offshore' ),
            ) // Args
        );
        add_action( 'admin_enqueue_scripts', array( $this, 'upload_scripts' ) );
        add_action( 'admin_footer', array( $this, 'custom_script' ) );
    }

    /**
     * Upload the Javascripts for the media uploader
     */
    public function upload_scripts() {
        // wp_enqueue_media();
        wp_enqueue_style( 'fontawesome', OFFSHORE_CSS_URL . '/font-awesome.min.css', false, '4.5.0' );
        wp_enqueue_style( 'selectize', OFFSHORE_CSS_URL . '/selectize.css', false, '0.12.1' );
        wp_enqueue_script( 'selectize', OFFSHORE_JS_URL . '/selectize.min.js', array( 'jquery' ), '0.12.1', false );
    }

    public function custom_script() { ?>
        <script type="text/javascript">
            jQuery(document).ready(function($){
                jQuery(document).on('click','.widget-title,.widget-title-action,.widget-control-save', function(){
                    var select = jQuery(this).parent().next().find('.offshore-select-contact-box');
                    if( !select.hasClass('selectized') ){
                        select.selectize({
                            options: [
                                {id: 'fa-map-marker'},
                                {id: 'fa-phone'},
                                {id: 'fa-file-audio-o'},
                            ],
                            create: false,
                            valueField: 'id',
                            labelField: 'id',
                            searchField: 'id',
                            sortField: 'text',
                            render: {
                                option: function(item, escape) {
                                    return '<span style="">' +
                                        '<i id="'+ item.id +'" class="fa '+ item.id +'" title="'+ item.id +'" style="font-size:32px;width:30px!important;height:50px!important;"></i>' +
                                    '</span>';
                                }
                            }
                        });
                    };
                });
                jQuery(document).on('click','.widget-control-save', function(){
                    $(this).ajaxComplete(function(event, XMLHttpRequest, ajaxOptions) {
                        var select = jQuery(this).parent().parent().parent().find('.offshore-select-contact-box');
                        if( !select.hasClass('selectized') ){
                            select.selectize({
                                options: [
                                    {id: 'fa-map-marker'},
                                    {id: 'fa-phone'},
                                    {id: 'fa-file-audio-o'},
                                ],
                                create: false,
                                valueField: 'id',
                                labelField: 'id',
                                searchField: 'id',
                                sortField: 'text',
                                render: {
                                    option: function(item, escape) {
                                        return '<span style="">' +
                                            '<i id="'+ item.id +'" class="fa '+ item.id +'" title="'+ item.id +'" style="font-size:32px;width:30px!important;height:50px!important;"></i>' +
                                        '</span>';
                                    }
                                }
                            });
                        };
                    });
                });
            });
        </script>
    <?php }


    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $icon = '';
        if( isset( $instance['icon'] ) ) {
            $icon = $instance['icon'];
        }
        $title = '';
        if( isset( $instance['title'] ) ) {
            $title = $instance['title'];
        }
        $description = '';
        if( isset( $instance['description'] ) ) {
            $description = $instance['description'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'icon' ) ); ?>"><?php esc_html_e( 'Icon:', 'offshore' ); ?></label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'icon' ) ); ?>"  name="<?php echo esc_attr( $this->get_field_name( 'icon' ) ); ?>" class="offshore-select-contact-box">
                <option value="<?php echo esc_attr( $icon ); ?>"><?php echo esc_html( $icon ); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>"><?php esc_html_e( 'Description:', 'offshore' ); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>" ><?php echo esc_textarea( $description ); ?></textarea>
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['icon'] = ( ! empty( $new_instance['icon'] ) ) ? sanitize_text_field( $new_instance['icon'] ) : '';
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['description'] = ( ! empty( $new_instance['description'] ) ) ? wp_kses_post( $new_instance['description'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['title'] ) ) {
            ?>
                <div class="contact-box">
                    <i class="fa <?php echo esc_attr( $instance['icon'] ); ?>" aria-hidden="true"></i>
                    <div class="contact-details">
                        <h4 class="pre-footer-title"><?php echo esc_html( $instance['title'] ); ?></h4>
                        <?php echo wpautop( $instance['description'] ); ?>
                    </div>
                </div>
            <?php
        }
        echo $args['after_widget'];
    }

} // class Offshore_Download_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_Contact_Box_Widget");' ) );

/**
 * Adds Offshore_Newsletter_Widget widget.
 */
class Offshore_Newsletter_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'offshore_newsletter_widget', // Base ID
            esc_html__( 'Offshore Newsletter', 'offshore' ), // Name
            array( 
                'description' => esc_html__( 'Displays subscription form.', 'offshore' )
            ) // Args
        );
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        $title = esc_html__( 'Newsletter', 'offshore' );
        if( isset( $instance['title'] ) ) {
            $title = $instance['title'];
        }
        $description = '';
        if( isset( $instance['description'] ) ) {
            $description = $instance['description'];
        }
        $email = '';
        if( isset( $instance['email'] ) ) {
            $email = $instance['email'];
        }
        $button_text = '';
        if( isset( $instance['button_text'] ) ) {
            $button_text = $instance['button_text'];
        }
        $form_action = '';
        if( isset( $instance['form_action'] ) ) {
            $form_action = $instance['form_action'];
        }
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'form_action' ) ); ?>"><?php esc_html_e( 'Form Action:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'form_action' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'form_action' ) ); ?>" type="text" value="<?php echo esc_attr( $form_action ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>"><?php esc_html_e( 'Description:', 'offshore' ); ?></label>
            <textarea class="widefat" rows="8" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>" ><?php echo esc_textarea( $description ); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>"><?php esc_html_e( 'Email Placeholder:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email' ) ); ?>" type="text" value="<?php echo esc_attr( $email ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'offshore' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>">
        </p>
        <?php 
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['form_action'] = ( ! empty( $new_instance['form_action'] ) ) ? sanitize_text_field( $new_instance['form_action'] ) : '';
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
        $instance['description'] = ( ! empty( $new_instance['description'] ) ) ? wp_kses_post( $new_instance['description'] ) : '';
        $instance['button_text'] = ( ! empty( $new_instance['button_text'] ) ) ? sanitize_text_field( $new_instance['button_text'] ) : '';
        $instance['email'] = ( ! empty( $new_instance['email'] ) ) ? sanitize_text_field( $new_instance['email'] ) : '';
        return $instance;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        if ( ! empty( $instance['email'] ) && ! empty( $instance['form_action'] ) ) {
            ?>
                <div class="newsletter widget">
                    <h2 class="widget-title"><?php echo esc_html( $instance['title'] ); ?></h2>
                    <p><?php echo esc_html( $instance['description'] ); ?></p>
                    <form id="offshore-mc-form" action="<?php echo admin_url( 'admin-ajax.php' ); ?>">
                        <div class="form-group">
                            <input type="email" id="mc-email" name="email" placeholder="<?php echo esc_attr( $instance['email'] ); ?>">
                        </div>
                        <button type="submit" class="btn btn-block"><?php echo esc_html( $instance['button_text'] ); ?></button>
                    </form>
                    <p id="offshore-mc-result" style="display:none;"></p>
                    <a id="offshore-mc-try" href="javascript:void(0)" style="display:none;"><?php esc_html_e( 'Try again', 'offshore' ); ?></a>
                </div>
                <script type="text/javascript">
                    jQuery(document).ready(function($){
                        $('#offshore-mc-form').ajaxChimp({
                            url: '<?php echo esc_url_raw( $instance["form_action"] ); ?>',
                            callback: mcCallback
                        });
                        $('#offshore-mc-try').on('click',function(){
                            $( '#offshore-mc-result, #offshore-mc-try' ).fadeToggle( 'fast', function(){
                                $( '#offshore-mc-form' ).fadeIn( 'fast' );
                            });
                        });
                    });
                    function mcCallback (resp) {
                        var txt = resp.msg.replace( '0 - ', '' );
                        jQuery( '#offshore-mc-result' ).text( txt );
                        jQuery( '#offshore-mc-form' ).fadeToggle( 'fast', function(){
                            if (resp.result !== 'success') {
                                jQuery( '#offshore-mc-result, #offshore-mc-try' ).fadeToggle( 'fast' );
                            } else {
                                jQuery( '#offshore-mc-result' ).fadeToggle( 'fast' );
                            }
                        });
                    }
                </script>
            <?php
        } else {
            echo '<p>';
            esc_html_e( 'Missing either form action or email parameter for Offshore Newsletter Widget', 'offshore' );
            echo '</p>';
        }
        echo $args['after_widget'];
    }

} // class Offshore_Call_To_Action_Widget
add_action( 'widgets_init', create_function( '', 'register_widget("Offshore_Newsletter_Widget");' ) );