<?php
/**
 * Demo functionality
 * @since 1.0.7
 */

/**
 * Display admin error message if PHP version is older than 5.3.2.
 * Otherwise execute the main plugin class.
 */
if ( version_compare( phpversion(), '5.3.2', '<' ) ) {

	/**
	 * Display an admin error notice when PHP is older the version 5.3.2.
	 * Hook it to the 'admin_notices' action.
	 */
	function offshore_old_php_admin_error_notice() {
		$message = sprintf( esc_html__( 'This theme requires %2$sPHP 5.3.2+%3$s to run properly. Please contact your hosting company and ask them to update the PHP version of your site to at least PHP 5.3.2.%4$s Your current version of PHP: %2$s%1$s%3$s', 'offshore' ), phpversion(), '<strong>', '</strong>', '<br>' );

		printf( '<div class="notice notice-error"><p>%1$s</p></div>', wp_kses_post( $message ) );
	}
	add_action( 'admin_notices', 'offshore_old_php_admin_error_notice' );
}
else {

	// Require main plugin file.
	require OFFSHORE_DEMO_DIR . 'inc/class-std-main.php';

	// Instantiate the main plugin class *Singleton*.
	$Theme_Setup = STD_Theme_Setup::getInstance();
}

// Import Files
function offshore_import_files() {
	return array(
		array(
			'import_file_name'             => 'Demo Import 1',
			'local_import_file'            => trailingslashit( OFFSHORE_PARENT_DIR ) . 'demo/data/content.xml',
			'local_import_widget_file'     => trailingslashit( OFFSHORE_PARENT_DIR ) . 'demo/data/widgets.wie',
			'local_import_customizer_file' => trailingslashit( OFFSHORE_PARENT_DIR ) . 'demo/data/customizer.dat',
			'import_preview_image_url'     => trailingslashit( OFFSHORE_PARENT_DIR ) . 'demo/data/screenshot.png',
			'import_notice'                => __( 'After you import this demo, you will have to setup the slider separately.', 'offshore' ),
			'preview_url'                  => 'http://demo.thewebsitedev.com/offshore/',
		),
	);
}
add_filter( 'std/import_files', 'offshore_import_files' );

// Auto assign front page and blog page
function offshore_after_import_setup() {

	// Assign front page and posts page (blog page).
	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );

}
add_action( 'std/after_import', 'offshore_after_import_setup' );

// Redirect user to theme set up page
global $pagenow;
if ( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {
	wp_redirect(admin_url("themes.php?page=theme-setup"));
}