<?php
/**
 * Main Theme Demo class/file.
 *
 * @package offshore
 */

// Include files.
require OFFSHORE_DEMO_DIR . 'inc/class-std-helpers.php';
require OFFSHORE_DEMO_DIR . 'inc/class-std-importer.php';
require OFFSHORE_DEMO_DIR . 'inc/class-std-widget-importer.php';
require OFFSHORE_DEMO_DIR . 'inc/class-std-customizer-importer.php';
require OFFSHORE_DEMO_DIR . 'inc/class-std-logger.php';

/**
 * Theme Demo Import class, so we don't have to worry about namespaces.
 */
class STD_Theme_Setup {

	/**
	 * @var $instance the reference to *Singleton* instance of this class
	 */
	private static $instance;

	/**
	 * Private variables used throughout the plugin.
	 */
	private $importer, $plugin_page, $theme_page, $import_files, $logger, $log_file_path, $selected_index, $selected_import_files, $microtime, $frontend_error_messages, $ajax_call_number;

	/**
	 * TGMPA instance storage
	 *
	 * @var object
	 */
	protected $tgmpa_instance;

	/**
	 * TGMPA Menu slug
	 *
	 * @var string
	 */
	protected $tgmpa_menu_slug = 'tgmpa-install-plugins';

	/**
	 * TGMPA Menu url
	 *
	 * @var string
	 */
	protected $tgmpa_url = 'themes.php?page=tgmpa-install-plugins';

	/**
	 * Returns the *Singleton* instance of this class.
	 *
	 * @return Theme_Demo_Import the *Singleton* instance.
	 */
	public static function getInstance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}


	/**
	 * Class construct function, to initiate the plugin.
	 * Protected constructor to prevent creating a new instance of the
	 * *Singleton* via the `new` operator from outside of this class.
	 */
	protected function __construct() {

		// Actions.
		add_action( 'admin_menu', array( $this, 'create_theme_page' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_action( 'wp_ajax_STD_import_demo_data', array( $this, 'import_demo_data_ajax_callback' ) );
		add_action( 'after_setup_theme', array( $this, 'setup_plugin_with_filter_data' ) );
		add_filter( 'tgmpa_load', array( $this, 'tgmpa_load' ), 10, 1 );
		add_action( 'wp_ajax_std_setup_plugins', array( $this, 'ajax_plugins' ) );
	}


	/**
	 * Private clone method to prevent cloning of the instance of the *Singleton* instance.
	 *
	 * @return void
	 */
	private function __clone() {}


	/**
	 * Private unserialize method to prevent unserializing of the *Singleton* instance.
	 *
	 * @return void
	 */
	private function __wakeup() {}

	public function tgmpa_load( $status ) {
		return is_admin() || current_user_can( 'install_themes' );
	}

	/**
	 * Get configured TGMPA instance
	 *
	 * @access public
	 * @since 1.1.2
	 */
	public function get_tgmpa_instanse(){
		$this->tgmpa_instance = call_user_func( array( get_class( $GLOBALS['tgmpa'] ), 'get_instance' ) );
	}

	/**
	 * Update $tgmpa_menu_slug and $tgmpa_parent_slug from TGMPA instance
	 *
	 * @access public
	 * @since 1.1.2
	 */
	public function set_tgmpa_url(){

		$this->tgmpa_menu_slug = ( property_exists($this->tgmpa_instance, 'menu') ) ? $this->tgmpa_instance->menu : $this->tgmpa_menu_slug;
		$this->tgmpa_menu_slug = apply_filters($this->theme_name . '_theme_setup_wizard_tgmpa_menu_slug', $this->tgmpa_menu_slug);

		$tgmpa_parent_slug = ( property_exists($this->tgmpa_instance, 'parent_slug') && $this->tgmpa_instance->parent_slug !== 'themes.php' ) ? 'admin.php' : 'themes.php';

		$this->tgmpa_url = apply_filters($this->theme_name . '_theme_setup_wizard_tgmpa_url', $tgmpa_parent_slug.'?page='.$this->tgmpa_menu_slug);

	}

	private function _get_plugins() {
		$instance = call_user_func( array( get_class( $GLOBALS['tgmpa'] ), 'get_instance' ) );
		$plugins = array(
			'all'      => array(), // Meaning: all plugins which still have open actions.
			'install'  => array(),
			'update'   => array(),
			'activate' => array(),
		);

		foreach ( $instance->plugins as $slug => $plugin ) {
			if ( $instance->is_plugin_active( $slug ) && false === $instance->does_plugin_have_update( $slug ) ) {
				// No need to display plugins if they are installed, up-to-date and active.
				continue;
			} else {
				$plugins['all'][ $slug ] = $plugin;

				if ( ! $instance->is_plugin_installed( $slug ) ) {
					$plugins['install'][ $slug ] = $plugin;
				} else {
					if ( false !== $instance->does_plugin_have_update( $slug ) ) {
						$plugins['update'][ $slug ] = $plugin;
					}

					if ( $instance->can_plugin_activate( $slug ) ) {
						$plugins['activate'][ $slug ] = $plugin;
					}
				}
			}
		}
		return $plugins;
	}

	/**
	 * Page setup
	 */
	public function setup_default_plugins() {

		tgmpa_load_bulk_installer();
		// install plugins with TGM.
		if ( ! class_exists( 'TGM_Plugin_Activation' ) || ! isset( $GLOBALS['tgmpa'] ) ) {
			die( 'Failed to find TGM' );
		}
		$url = wp_nonce_url( add_query_arg( array( 'plugins' => 'go' ) ), 'std-setup' );
		$plugins = $this->_get_plugins();

		// copied from TGM

		$method = ''; // Leave blank so WP_Filesystem can populate it as necessary.
		$fields = array_keys( $_POST ); // Extra fields to pass to WP_Filesystem.

		if ( false === ( $creds = request_filesystem_credentials( esc_url_raw( $url ), $method, false, false, $fields ) ) ) {
			return true; // Stop the normal page form from displaying, credential request form will be shown.
		}

		// Now we have some credentials, setup WP_Filesystem.
		if ( ! WP_Filesystem( $creds ) ) {
			// Our credentials were no good, ask the user for them again.
			request_filesystem_credentials( esc_url_raw( $url ), $method, true, false, $fields );

			return true;
		}

		/* If we arrive here, we have the filesystem */

		?>
        <h3><?php esc_html_e( 'Recommended Plugins', 'offshore' ); ?></h3>
        <form method="post">

			<?php
			$plugins = $this->_get_plugins();
			if ( count( $plugins['all'] ) ) {
				?>
                <p><?php esc_html_e( 'Your website needs a few essential plugins. The following plugins will be installed:', 'offshore' ); ?></p>
                <ol class="std-setup-plugins">
					<?php foreach ( $plugins['all'] as $slug => $plugin ) {  ?>
                        <li data-slug="<?php echo esc_attr( $slug );?>"><?php echo esc_html( $plugin['name'] );?>
                            <span style="font-style:italic;font-size:10px;color:#909090;">
                                <?php
                                $keys = array();
                                if ( isset( $plugins['install'][ $slug ] ) ) { $keys[] = 'Installation'; }
                                if ( isset( $plugins['update'][ $slug ] ) ) { $keys[] = 'Update'; }
                                if ( isset( $plugins['activate'][ $slug ] ) ) { $keys[] = 'Activation'; }
                                echo implode( ' and ',$keys ).' required';
                                ?>
                            </span>
                            <div class="spinner"></div>
                        </li>
					<?php } ?>
                </ol>
				<?php
			} else {
				echo '<p><strong>'._e( 'Good news! All plugins are already installed and up to date. Please go ahead and install demo content if not installed already.','offshore' ).'</strong></p>';
			} ?>

            <p>
                <?php
                    $plugins_page_url = admin_url( 'plugins.php' );
                    echo sprintf(__( 'You can add and remove plugins later from <a href="%1$s">plugins page</a>.', 'offshore' ), $plugins_page_url );
                ?>
            </p>
            <?php if ( count( $plugins['all'] ) ): ?>
                <a class="button button-hero button-primary button-next" data-callback="install_plugins"><?php esc_html_e( 'Install Plugins', 'offshore' ); ?></a>
            <?php endif; ?>
        </form>
		<?php
	}

	public function ajax_plugins() {
		if ( ! check_ajax_referer( 'std_setup_nonce', 'wpnonce' ) || empty( $_POST['slug'] ) ) {
			wp_send_json_error( array( 'error' => 1, 'message' => esc_html__( 'No Slug Found','offshore' ) ) );
		}
		$json = array();
		// send back some json we use to hit up TGM
		$plugins = $this->_get_plugins();
		// what are we doing with this plugin?
		foreach ( $plugins['activate'] as $slug => $plugin ) {
			if ( $_POST['slug'] == $slug ) {
				$json = array(
					'url' => admin_url( $this->tgmpa_url ),
					'plugin' => array( $slug ),
					'tgmpa-page' => $this->tgmpa_menu_slug,
					'plugin_status' => 'all',
					'_wpnonce' => wp_create_nonce( 'bulk-plugins' ),
					'action' => 'tgmpa-bulk-activate',
					'action2' => -1,
					'message' => esc_html__( 'Activating Plugin','offshore' ),
				);
				break;
			}
		}
		foreach ( $plugins['update'] as $slug => $plugin ) {
			if ( $_POST['slug'] == $slug ) {
				$json = array(
					'url' => admin_url( $this->tgmpa_url ),
					'plugin' => array( $slug ),
					'tgmpa-page' => $this->tgmpa_menu_slug,
					'plugin_status' => 'all',
					'_wpnonce' => wp_create_nonce( 'bulk-plugins' ),
					'action' => 'tgmpa-bulk-update',
					'action2' => -1,
					'message' => esc_html__( 'Updating Plugin','offshore' ),
				);
				break;
			}
		}
		foreach ( $plugins['install'] as $slug => $plugin ) {
			if ( $_POST['slug'] == $slug ) {
				$json = array(
					'url' => admin_url( $this->tgmpa_url ),
					'plugin' => array( $slug ),
					'tgmpa-page' => $this->tgmpa_menu_slug,
					'plugin_status' => 'all',
					'_wpnonce' => wp_create_nonce( 'bulk-plugins' ),
					'action' => 'tgmpa-bulk-install',
					'action2' => -1,
					'message' => esc_html__( 'Installing Plugin','offshore' ),
				);
				break;
			}
		}

		if ( $json ) {
			$json['hash'] = md5( serialize( $json ) ); // used for checking if duplicates happen, move to next plugin
			wp_send_json( $json );
		} else {
			wp_send_json( array( 'done' => 1, 'message' => esc_html__( 'Success','offshore' ) ) );
		}
		exit;

	}


	/**
	 * Creates the plugin page and a submenu item in WP Appearance menu.
	 */
	public function create_theme_page() {

		$theme_page_setup = array(
            'page_title'  => esc_html__( 'Offshore Setup' , 'offshore' ),
            'menu_title'  => esc_html__( 'Offshore Setup' , 'offshore' ),
            'capability'  => 'import',
            'menu_slug'   => 'theme-setup',
		);

		$this->theme_page = add_theme_page( $theme_page_setup['page_title'], $theme_page_setup['menu_title'], $theme_page_setup['capability'], $theme_page_setup['menu_slug'], array( $this, 'display_theme_page' ) );

	}

	/**
	 * Theme page display.
	 */
	public function display_theme_page() {

		$plugin_Screen = ( isset( $_GET['action'] ) && 'plugin' == $_GET['action'] ) ? true : false;
		$demo_Screen = ( isset( $_GET['action'] ) && 'demo' == $_GET['action'] ) ? true : false;
		$slider_Screen = ( isset( $_GET['action'] ) && 'slider' == $_GET['action'] ) ? true : false;
		$faq_Screen = ( isset( $_GET['action'] ) && 'faq' == $_GET['action'] ) ? true : false;
		$changelog_Screen = ( isset( $_GET['action'] ) && 'changelog' == $_GET['action'] ) ? true : false;

		?>
        <div class="std wrap about-wrap">
            <h1>
                <?php
                    $theme = wp_get_theme();
                    $theme_setup_url = admin_url( 'themes.php?page=theme-setup' );
                    echo sprintf( __('%1$s Setup','offshore'), $theme->get( 'Name' ) );
                ?>
            </h1>
            <p class="about-text"><?php echo sprintf(__('You will find everything you need to get started with %1$s below.','offshore'), $theme->get( 'Name' )); ?></p>

            <?php
                // Display warning if PHP safe mode is enabled, since we wont be able to change the max_execution_time.
                if ( ini_get( 'safe_mode' ) ) {
                    printf(
                    esc_html__( '%sWarning: your server is using %sPHP safe mode%s. This means that you might experience server timeout errors.%s', 'offshore' ),
                    '<div class="notice  notice-warning  is-dismissible"><p>',
                            '<strong>',
                                '</strong>',
                            '</p></div>'
                    );
                }

                $memory_limit = ini_get( 'memory_limit' );

                // Display warning if PHP memory limit is below 300M, since we wont be able to change the max_execution_time.
                if ( $memory_limit && (int) str_replace('M','', $memory_limit) < 300 ) {
                    printf(
                    wp_kses_post( __( '%sScript max execution time is %s%s%s. This means that you might experience server timeout errors on slow servers.%sIf possible, <a href="%s" target="_blank">increase</a> it to 300M.%s', 'offshore' ) ),
                '<div class="notice  notice-warning  is-dismissible"><p>','<strong>', $memory_limit, '</strong>', '<br>', 'https://docs.woocommerce.com/document/increasing-the-wordpress-memory-limit/', '</p></div>'
                    );
                }
            ?>

            <h2 class="nav-tab-wrapper wp-clearfix">
                <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'plugin' ), $theme_setup_url ) ); ?>" class="nav-tab<?php if ( ! isset( $_GET['action'] ) || $plugin_Screen ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Plugins', 'offshore' ); ?></a>
                <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'demo' ), $theme_setup_url ) ); ?>" class="nav-tab<?php if ( $demo_Screen ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Demo Content', 'offshore' ); ?></a>
                <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'slider' ), $theme_setup_url ) ); ?>" class="nav-tab<?php if ( $slider_Screen ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Slider', 'offshore' ); ?></a>
                <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'faq' ), $theme_setup_url ) ); ?>" class="nav-tab<?php if ( $faq_Screen ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'FAQ & Support', 'offshore' ); ?></a>
                <a href="<?php echo esc_url( add_query_arg( array( 'action' => 'changelog' ), $theme_setup_url ) ); ?>" class="nav-tab<?php if ( $changelog_Screen ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Changelog', 'offshore' ); ?></a>
            </h2>

            <?php // settings_fields( 'vaajo_general' );
				if($demo_Screen) { ?>
					<div class="std wrap about-wrap">
                        <div class="STD__intro-notice notice notice-warning is-dismissible">
                            <p><?php esc_html_e( 'Before you begin, make sure all the required plugins are activated.', 'offshore' ); ?></p>
                        </div>

                        <?php
                        // Start output buffer for displaying the plugin intro text.
                        ob_start();
                        ?>

                            <div class="STD__intro-text">

                                <p class="">
                                    <?php esc_html_e( 'Ready to set up your website as shown in the demo?', 'offshore' ); ?>
                                </p>

                                <h4><?php esc_html_e( 'The following data will be imported:', 'offshore' ); ?></h4>

                                <ul>
                                    <li><?php esc_html_e( 'Posts', 'offshore' ); ?></li>
                                    <li><?php esc_html_e( 'Pages', 'offshore' ); ?></li>
                                    <li><?php esc_html_e( 'Images', 'offshore' ); ?></li>
                                    <li><?php esc_html_e( 'Widgets', 'offshore' ); ?></li>
                                    <li><?php esc_html_e( 'Menus', 'offshore' ); ?></li>
                                    <li><?php esc_html_e( 'Settings', 'offshore' ); ?></li>
                                </ul>
                                <br>
                                <p><?php esc_html_e( 'Note: Your existing content will NOT be deleted or modified.', 'offshore' ); ?></p>

                                <hr>

                            </div>

                        <?php
                        $demo_intro_text = ob_get_clean();

                        // Display the plugin intro text (can be replaced with custom text through the filter below).
                        echo wp_kses_post( apply_filters( 'std/demo_intro_text', $demo_intro_text ) );

                        if ( empty( $this->import_files ) ) : ?>

                            <div class="notice  notice-info  is-dismissible">
                                <p><?php esc_html_e( 'There are no predefined import files available in this theme. Please upload the import files manually!', 'offshore' ); ?></p>
                            </div>

                            <div class="STD__file-upload-container">

                                <h2><?php esc_html_e( 'Manually upload the demo files', 'offshore' ); ?></h2>

                                <div class="STD__file-upload">
                                    <h3><label for="content-file-upload"><?php esc_html_e( 'Choose a XML file for content import:', 'offshore' ); ?></label></h3>
                                    <input id="STD__content-file-upload" type="file" name="content-file-upload">
                                </div>

                                <div class="STD__file-upload">
                                    <h3><label for="widget-file-upload"><?php esc_html_e( 'Choose a WIE or JSON file for widget import:', 'offshore' ); ?></label> <span><?php esc_html_e( '(*optional)', 'offshore' ); ?></span></h3>
                                    <input id="STD__widget-file-upload" type="file" name="widget-file-upload">
                                </div>

                                <div class="STD__file-upload">
                                    <h3><label for="customizer-file-upload"><?php esc_html_e( 'Choose a DAT file for customizer import:', 'offshore' ); ?></label> <span><?php esc_html_e( '(*optional)', 'offshore' ); ?></span></h3>
                                    <input id="STD__customizer-file-upload" type="file" name="customizer-file-upload">
                                </div>

                            </div>

                        <?php elseif ( 1 < count( $this->import_files ) ) : ?>

                            <div class="STD__multi-select-import">

                                <h2><?php esc_html_e( 'Choose which demo you want to import:', 'offshore' ); ?></h2>

                                <select id="STD__demo-import-files" class="STD__demo-import-files">
                                    <?php foreach ( $this->import_files as $index => $import_file ) : ?>
                                        <option value="<?php echo esc_attr( $index ); ?>">
                                            <?php echo esc_html( $import_file['import_file_name'] ); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>

                                <?php
                                // Check if at least one preview image is defined, so we can prepare the structure for display.
                                $preview_image_is_defined = false;
                                foreach ( $this->import_files as $import_file ) {
                                    if ( isset( $import_file['import_preview_image_url'] ) ) {
                                        $preview_image_is_defined = true;
                                        break;
                                    }
                                }

                                if ( $preview_image_is_defined ) :
                                    ?>

                                    <div class="STD__demo-import-preview-container">

                                        <p><?php esc_html_e( 'Import preview:', 'offshore' ); ?></p>

                                        <p class="STD__demo-import-preview-image-message  js-std-preview-image-message"><?php
                                            if ( ! isset( $this->import_files[0]['import_preview_image_url'] ) ) {
                                                esc_html_e( 'No preview image defined for this import.', 'offshore' );
                                            }
                                            // Leave the img tag below and the p tag above available for later changes via JS.
                                            ?></p>

                                        <img id="STD__demo-import-preview-image" class="js-std-preview-image" src="<?php echo ! empty( $this->import_files[0]['import_preview_image_url'] ) ? esc_url( $this->import_files[0]['import_preview_image_url'] ) : ''; ?>">

                                    </div>

                                <?php endif; ?>

                            </div>

                        <?php endif; ?>

                        <div class="STD__demo-import-notice  js-std-demo-import-notice"><?php
                            if ( is_array( $this->import_files ) && ! empty( $this->import_files[0]['import_notice'] ) ) {
                                echo wp_kses_post( $this->import_files[0]['import_notice'] );
                            }
                            ?></div>

                        <p class="STD__button-container">
                            <button class="STD__button button button-hero button-primary js-std-import-data"><?php esc_html_e( 'Import Demo Content', 'offshore' ); ?></button>
                            <span><?php esc_html_e( 'Click the button once and wait. The import process may take several minutes.', 'offshore' ); ?></span>
                        </p>

                        <p class="STD__ajax-loader js-std-ajax-loader">
                            <span class="spinner"></span> <?php esc_html_e( 'Importing, please wait!', 'offshore' ); ?>
                        </p>

                        <div class="STD__response js-std-ajax-response"></div>

                    </div>
                    <?php
				}
                elseif($slider_Screen) {
					get_template_part('demo/inc/pages/content', 'slider');
				}
				elseif($faq_Screen) {
					get_template_part('demo/inc/pages/content', 'help');
				}
                elseif($changelog_Screen) {
	                get_template_part('demo/inc/pages/content', 'changelog');
				}
				else {
					$this->setup_default_plugins();
				}
            ?>
        </div>
		<?php
	}


	/**
	 * Enqueue admin scripts (JS and CSS)
	 *
	 * @param string $hook holds info on which admin page you are currently loading.
	 */
	public function admin_enqueue_scripts( $hook ) {

		// Enqueue the scripts only on the plugin page.
		if ( $this->plugin_page === $hook || $this->theme_page === $hook) {
			wp_enqueue_script( 'std-main-js', OFFSHORE_DEMO_URL . 'assets/js/main.js' , array( 'jquery', 'jquery-form' ), OFFSHORE_PARENT_THEME_VERSION );

			wp_localize_script( 'std-main-js', 'std',
				array(
					'ajax_url'     => admin_url( 'admin-ajax.php' ),
					'ajax_nonce'   => wp_create_nonce( 'std-ajax-verification' ),
					'import_files' => $this->import_files,
					'texts'        => array(
						'missing_preview_image' => esc_html__( 'No preview image defined for this import.', 'offshore' ),
					),
					'tgm_plugin_nonce'            => array(
						'update' => wp_create_nonce( 'tgmpa-update' ),
						'install' => wp_create_nonce( 'tgmpa-install' ),
					),
					'tgm_bulk_url' => admin_url( $this->tgmpa_url ),
					'wpnonce' => wp_create_nonce( 'std_setup_nonce' ),
					'verify_text' => esc_html__( '...verifying','offshore' ),
				)
			);

			wp_enqueue_style( 'std-main-css', OFFSHORE_DEMO_URL . 'assets/css/main.css', array() , OFFSHORE_PARENT_THEME_VERSION );
		}
	}


	/**
	 * Main AJAX callback function for:
	 * 1. prepare import files (uploaded or predefined via filters)
	 * 2. import content
	 * 3. before widgets import setup (optional)
	 * 4. import widgets (optional)
	 * 5. import customizer options (optional)
	 * 6. after import setup (optional)
	 */
	public function import_demo_data_ajax_callback() {

		// Try to update PHP memory limit (so that it does not run out of it).

		// Verify if the AJAX call is valid (checks nonce and current_user_can).
		STD_Helpers::verify_ajax_call();

		// Is this a new AJAX call to continue the previous import?
		$use_existing_importer_data = $this->get_importer_data();

		if ( ! $use_existing_importer_data ) {

			// Set the AJAX call number.
			$this->ajax_call_number = empty( $this->ajax_call_number ) ? 0 : $this->ajax_call_number;

			// Error messages displayed on front page.
			$this->frontend_error_messages = '';

			// Create a date and time string to use for demo and log file names.
			$demo_import_start_time = date( apply_filters( 'std/date_format_for_file_names', 'Y-m-d__H-i-s' ) );

			// Define log file path.
			$this->log_file_path = STD_Helpers::get_log_path( $demo_import_start_time );

			// Get selected file index or set it to 0.
			$this->selected_index = empty( $_POST['selected'] ) ? 0 : absint( $_POST['selected'] );

			/**
			 * 1. Prepare import files.
			 * Manually uploaded import files or predefined import files via filter: std/import_files
			 */
			if ( ! empty( $_FILES ) ) { // Using manual file uploads?

				// Get paths for the uploaded files.
				$this->selected_import_files = STD_Helpers::process_uploaded_files( $_FILES, $this->log_file_path );

				// Set the name of the import files, because we used the uploaded files.
				$this->import_files[ $this->selected_index ]['import_file_name'] = esc_html__( 'Manually uploaded files', 'offshore' );
			}
			elseif ( ! empty( $this->import_files[ $this->selected_index ] ) ) { // Use predefined import files from wp filter: std/import_files.

				// Download the import files (content and widgets files) and save it to variable for later use.
				$this->selected_import_files = STD_Helpers::download_import_files(
					$this->import_files[ $this->selected_index ],
					$demo_import_start_time
				);

				// Check Errors.
				if ( is_wp_error( $this->selected_import_files ) ) {

					// Write error to log file and send an AJAX response with the error.
					STD_Helpers::log_error_and_send_ajax_response(
						$this->selected_import_files->get_error_message(),
						$this->log_file_path,
						esc_html__( 'Downloaded files', 'offshore' )
					);
				}

				// Add this message to log file.
				$log_added = STD_Helpers::append_to_file(
					sprintf(
						__( 'The import files for: %s were successfully downloaded!', 'offshore' ),
						$this->import_files[ $this->selected_index ]['import_file_name']
					) . STD_Helpers::import_file_info( $this->selected_import_files ),
					$this->log_file_path,
					esc_html__( 'Downloaded files' , 'offshore' )
				);
			}
			else {

				// Send JSON Error response to the AJAX call.
				wp_send_json( esc_html__( 'No import files specified!', 'offshore' ) );
			}
		}

		/**
		 * 2. Import content.
		 * Returns any errors greater then the "error" logger level, that will be displayed on front page.
		 */
		$this->frontend_error_messages .= $this->import_content( $this->selected_import_files['content'] );

		/**
		 * 3. Before widgets import setup.
		 */
		$action = 'std/before_widgets_import';
		if ( ( false !== has_action( $action ) ) && empty( $this->frontend_error_messages ) ) {

			// Run the before_widgets_import action to setup other settings.
			$this->do_import_action( $action, $this->import_files[ $this->selected_index ] );
		}

		/**
		 * 4. Import widgets.
		 */
		if ( ! empty( $this->selected_import_files['widgets'] ) && empty( $this->frontend_error_messages ) ) {
			$this->import_widgets( $this->selected_import_files['widgets'] );
		}

		/**
		 * 5. Import customize options.
		 */
		if ( ! empty( $this->selected_import_files['customizer'] ) && empty( $this->frontend_error_messages ) ) {
			$this->import_customizer( $this->selected_import_files['customizer'] );
		}

		/**
		 * 6. After import setup.
		 */
		$action = 'std/after_import';
		if ( ( false !== has_action( $action ) ) && empty( $this->frontend_error_messages ) ) {

			// Run the after_import action to setup other settings.
			$this->do_import_action( $action, $this->import_files[ $this->selected_index ] );
		}

		// Display final messages (success or error messages).
		if ( empty( $this->frontend_error_messages ) ) {
			$response['message'] = sprintf(
				__( '%1$sThat\'s it, all done!%2$sThe demo import has finished. Please check your page and make sure that everything has imported correctly.%3$s', 'offshore' ),
				'<div class="notice  notice-success"><p>',
				'<br>',
				'</p></div>'
			);
		}
		else {
			$response['message'] = $this->frontend_error_messages . '<br>';
			$response['message'] .= sprintf(
				__( '%1$sThe demo import has finished, but there were some import errors.%2$sMore details about the errors can be found in this %3$s%5$slog file%6$s%4$s%7$s', 'offshore' ),
				'<div class="notice  notice-error"><p>',
				'<br>',
				'<strong>',
				'</strong>',
				'<a href="' . STD_Helpers::get_log_url( $this->log_file_path ) .'" target="_blank">',
				'</a>',
				'</p></div>'
			);
		}

		wp_send_json( $response );
	}


	/**
	 * Import content from an WP XML file.
	 *
	 * @param string $import_file_path path to the import file.
	 */
	private function import_content( $import_file_path ) {

		$this->microtime = microtime( true );

		// This should be replaced with multiple AJAX calls (import in smaller chunks)
		// so that it would not come to the Internal Error, because of the PHP script timeout.
		// Also this function has no effect when PHP is running in safe mode
		// http://php.net/manual/en/function.set-time-limit.php.
		// Increase PHP max execution time.
		set_time_limit( apply_filters( 'std/set_time_limit_for_demo_data_import', 300 ) );

		// Disable import of authors.
		add_filter( 'wxr_importer.pre_process.user', '__return_false' );

		// Check, if we need to send another AJAX request and set the importing author to the current user.
		add_filter( 'wxr_importer.pre_process.post', array( $this, 'new_ajax_request_maybe' ) );

		// Disables generation of multiple image sizes (thumbnails) in the content import step.
		if ( ! apply_filters( 'std/regenerate_thumbnails_in_content_import', true ) ) {
			add_filter( 'intermediate_image_sizes_advanced',
				function() {
					return null;
				}
			);
		}

		// Import content.
		if ( ! empty( $import_file_path ) ) {
			ob_start();
				$this->importer->import( $import_file_path );
			$message = ob_get_clean();

			// Add this message to log file.
			$log_added = STD_Helpers::append_to_file(
				$message . PHP_EOL . esc_html__( 'Max execution time after content import = ' , 'offshore' ) . ini_get( 'max_execution_time' ),
				$this->log_file_path,
				esc_html__( 'Importing content' , 'offshore' )
			);
		}

		// Delete content importer data for current import from DB.
		delete_transient( 'STD_importer_data' );

		// Return any error messages for the front page output (errors, critical, alert and emergency level messages only).
		return $this->logger->error_output;
	}


	/**
	 * Import widgets from WIE or JSON file.
	 *
	 * @param string $widget_import_file_path path to the widget import file.
	 */
	private function import_widgets( $widget_import_file_path ) {

		// Widget import results.
		$results = array();

		// Create an instance of the Widget Importer.
		$widget_importer = new STD_Widget_Importer();

		// Import widgets.
		if ( ! empty( $widget_import_file_path ) ) {

			// Import widgets and return result.
			$results = $widget_importer->import_widgets( $widget_import_file_path );
		}

		// Check for errors.
		if ( is_wp_error( $results ) ) {

			// Write error to log file and send an AJAX response with the error.
			STD_Helpers::log_error_and_send_ajax_response(
				$results->get_error_message(),
				$this->log_file_path,
				esc_html__( 'Importing widgets', 'offshore' )
			);
		}

		ob_start();
			$widget_importer->format_results_for_log( $results );
		$message = ob_get_clean();

		// Add this message to log file.
		$log_added = STD_Helpers::append_to_file(
			$message,
			$this->log_file_path,
			esc_html__( 'Importing widgets' , 'offshore' )
		);
	}


	/**
	 * Import customizer from a DAT file, generated by the Customizer Export/Import plugin.
	 *
	 * @param string $customizer_import_file_path path to the customizer import file.
	 */
	private function import_customizer( $customizer_import_file_path ) {

		// Try to import the customizer settings.
		$results = STD_Customizer_Importer::import_customizer_options( $customizer_import_file_path );

		// Check for errors.
		if ( is_wp_error( $results ) ) {

			// Write error to log file and send an AJAX response with the error.
			STD_Helpers::log_error_and_send_ajax_response(
				$results->get_error_message(),
				$this->log_file_path,
				esc_html__( 'Importing customizer settings', 'offshore' )
			);
		}

		// Add this message to log file.
		$log_added = STD_Helpers::append_to_file(
			esc_html__( 'Customizer settings import finished!', 'offshore' ),
			$this->log_file_path,
			esc_html__( 'Importing customizer settings' , 'offshore' )
		);
	}


	/**
	 * Setup other things in the passed wp action.
	 *
	 * @param string $action the action name to be executed.
	 * @param array  $selected_import with information about the selected import.
	 */
	private function do_import_action( $action, $selected_import ) {

		ob_start();
			do_action( $action, $selected_import );
		$message = ob_get_clean();

		// Add this message to log file.
		$log_added = STD_Helpers::append_to_file(
			$message,
			$this->log_file_path,
			$action
		);
	}


	/**
	 * Check if we need to create a new AJAX request, so that server does not timeout.
	 *
	 * @param array $data current post data.
	 * @return array
	 */
	public function new_ajax_request_maybe( $data ) {
		$time = microtime( true ) - $this->microtime;

		// We should make a new ajax call, if the time is right.
		if ( $time > apply_filters( 'std/time_for_one_ajax_call', 25 ) ) {
			$this->ajax_call_number++;
			$this->set_importer_data();

			$response = array(
				'status'  => 'newAJAX',
				'message' => 'Time for new AJAX request!: ' . $time,
			);

			// Add any output to the log file and clear the buffers.
			$message = ob_get_clean();

			// Add message to log file.
			$log_added = STD_Helpers::append_to_file(
				__( 'Completed AJAX call number: ' , 'offshore' ) . $this->ajax_call_number . PHP_EOL . $message,
				$this->log_file_path,
				''
			);

			wp_send_json( $response );
		}

		// Set importing author to the current user.
		// Fixes the [WARNING] Could not find the author for ... log warning messages.
		$current_user_obj    = wp_get_current_user();
		$data['post_author'] = $current_user_obj->user_login;

		return $data;
	}


	/**
	 * Set current state of the content importer, so we can continue the import with new AJAX request.
	 */
	private function set_importer_data() {
		$data = array(
			'frontend_error_messages' => $this->frontend_error_messages,
			'ajax_call_number'        => $this->ajax_call_number,
			'log_file_path'           => $this->log_file_path,
			'selected_index'          => $this->selected_index,
			'selected_import_files'   => $this->selected_import_files,
		);

		$data = array_merge( $data, $this->importer->get_importer_data() );

		set_transient( 'STD_importer_data', $data, 0.5 * HOUR_IN_SECONDS );
	}


	/**
	 * Get content importer data, so we can continue the import with this new AJAX request.
	 */
	private function get_importer_data() {
		if ( $data = get_transient( 'STD_importer_data' ) ) {
			$this->frontend_error_messages                = empty( $data['frontend_error_messages'] ) ? '' : $data['frontend_error_messages'];
			$this->ajax_call_number                       = empty( $data['ajax_call_number'] ) ? 1 : $data['ajax_call_number'];
			$this->log_file_path                          = empty( $data['log_file_path'] ) ? '' : $data['log_file_path'];
			$this->selected_index                         = empty( $data['selected_index'] ) ? 0 : $data['selected_index'];
			$this->selected_import_files                  = empty( $data['selected_import_files'] ) ? array() : $data['selected_import_files'];
			$this->importer->set_importer_data( $data );

			return true;
		}
		return false;
	}


	/**
	 * Get data from filters, after the theme has loaded and instantiate the importer.
	 */
	public function setup_plugin_with_filter_data() {

		// Get info of import data files and filter it.
		$this->import_files = STD_Helpers::validate_import_file_info( apply_filters( 'std/import_files', array() ) );

		// Importer options array.
		$importer_options = apply_filters( 'std/importer_options', array(
			'fetch_attachments' => true,
		) );

		// Logger options for the logger used in the importer.
		$logger_options = apply_filters( 'std/logger_options', array(
			'logger_min_level' => 'warning',
		) );

		// Configure logger instance and set it to the importer.
		$this->logger            = new STD_Logger();
		$this->logger->min_level = $logger_options['logger_min_level'];

		// Create importer instance with proper parameters.
		$this->importer = new STD_Importer( $importer_options, $this->logger );
	}
}
