<?php 

/**
 * Breadcrumbs
 * @since 1.0.0
 * @author Rachel Baker
 * @link https://github.com/rachelbaker/bootstrapwp-Twitter-Bootstrap-for-WordPress/blob/master/functions.php
 * Adds breadcrumbs and hooks them into offshore_content_before.
 * Based on Rachel Baker's Twitter Bootstrap for WordPress theme
 */
if ( !function_exists( 'offshore_breadcrumbs' ) ) {
    
    function offshore_breadcrumbs() {
        
        global $post, $paged;

        if( isset( $post->ID ) ){
            $meta = get_post_meta( $post->ID, 'offshore_options', true );
        } else {
            $meta = array();
        }

        if( !isset( $meta['hide_breadcrumbs'] ) ){
            $meta['hide_breadcrumbs'] = 'global';
        }

        if( '1' == get_theme_mod( 'hide_breadcrumbs', '0' ) && $meta['hide_breadcrumbs'] == 'global' || $meta['hide_breadcrumbs'] == 'yes' ){
            return;
        }

        // show on blog page but not on front page
        $front_page_ID = get_option( 'page_on_front' );

        if( !is_object( $post ) ){
            $post_ID = '';
        }else{
            $post_ID = $post->ID;
        }
        
        if( $front_page_ID != $post_ID ) {

            if ( !is_home() || !is_front_page() ) {

                echo '<!-- Breadcrumbs --><div class="breadcrumbs"><div class="container">';

                if ( !is_paged() ) {

                    echo '<span class="parent"><i class="fa fa-home"></i><a href="' . esc_url( trailingslashit( get_home_url() ) ) . '">' . esc_html__( 'Home', 'offshore' ) . '</a></span>';

                    if ( is_category() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        $category = get_the_category();
                        if ($category) {
                            foreach($category as $category) {
                                echo '<span class="child"><a href="' . esc_url(get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a></span><i class="fa fa-chevron-right"></i>';
                            }
                        }
                        echo '<span class="child">' . sprintf( esc_html__( 'Posts filed under %s', 'offshore' ), single_cat_title( '', false ) ) . '</span>';
                    } elseif ( is_day() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child"><a href="' . esc_url( get_year_link( get_the_time('Y') ) ) . '">' . esc_html( get_the_time('Y') ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        echo '<span class="child"><a href="' . esc_url(  get_month_link( get_the_time('Y'), get_the_time('m') ) ) . '">' . esc_html( get_the_time('F') ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html( get_the_time('d') ) . '</span>';
                    } elseif ( is_month() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child"><a href="' . esc_url( get_year_link( get_the_time('Y') ) ) . '">' . esc_html( get_the_time('Y') ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html( get_the_time('F') ) . '</span>';
                    } elseif ( is_year() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html( get_the_time('Y') ) . '</span>';
                    } elseif ( is_single() && !is_attachment() && !is_search() ) {
                        if ( get_post_type() != 'post' ) {
                            echo '<i class="fa fa-chevron-right"></i>';
                            $post_type = get_post_type_object( get_post_type() );
                            $slug = $post_type->rewrite;
                            echo '<span class="child"><a href="' . esc_url( home_url() . '/' . $slug['slug'] ) . '/">' . esc_html( $post_type->labels->singular_name ) . '</a></span><i class="fa fa-chevron-right"></i>';
                            echo '<span class="child">' . esc_html( get_the_title() ) . '</span>';
                        } else {
                            echo '<i class="fa fa-chevron-right"></i>';
                            $category = get_the_category();
                            if ($category) {
                                foreach($category as $category) {
                                    echo '<span class="child"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a></span><i class="fa fa-chevron-right"></i>';
                                }
                            }
                            echo '<span class="child">' . esc_html( get_the_title() ) . '</span>';
                        }
                    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_archive() && !is_search() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        $post_type = get_post_type_object( get_post_type() );
                        echo '<span class="child">' . esc_html( $post_type->labels->singular_name ) . '</span>';
                    } elseif ( is_archive() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        $post_type = get_post_type_object( get_post_type() );
                        echo '<span class="child">' . esc_html( $post_type->labels->name ) . '</span>';
                    } elseif ( is_attachment() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        $parent = get_post( $post->post_parent );
                        $category = get_the_category( $parent->ID );
                        if ( $category ) {
                            foreach($category as $category) {
                                echo '<span class="child"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a></span><i class="fa fa-chevron-right"></i>';
                            }
                        }
                        echo '<span class="child">' . esc_html( get_the_title() ) . '</span>';
                    } elseif ( is_page() && !$post->post_parent ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html( get_the_title() ) . '</span>';
                    } elseif ( is_page() && $post->post_parent ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        $parent_id = $post->post_parent;
                        $breadcrumbs = array();
                        if( $parent_id ) {
                            $page = get_post($parent_id);
                            $breadcrumbs[] = '<span class="child"><a href="' . esc_url( get_permalink( $page->ID ) ) . '">' . esc_html( get_the_title( $page->ID ) ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        }
                        $breadcrumbs = array_reverse( $breadcrumbs );
                        foreach ( $breadcrumbs as $crumb ) {
                            echo $crumb;
                        }
                        echo '<span class="child">' . esc_html( get_the_title() ) . '</span>';
                    } elseif ( is_search() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . sprintf( esc_html__( 'Search results for %s', 'offshore' ), get_search_query() ) . '</span>';
                    } elseif ( is_tag() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . sprintf( esc_html__( 'Posts tagged %s', 'offshore' ), single_tag_title( '', false ) ) . '</span>';
                    } elseif ( is_author() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        global $author;
                        echo '<span class="child">' . sprintf( esc_html__( 'All posts by %s', 'offshore' ), get_the_author_meta( 'display_name', $author ) ) . '</span>';
                    } elseif ( is_404() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html__( 'Error 404', 'offshore' ) . '</span>';
                    } else {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . esc_html__( 'Blog', 'offshore' ) . '</span>';
                    }
                }
                if ( is_paged() ) {
                    $blog_page_ID = get_option( 'page_for_posts' );
                    if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) {
                        echo '<i class="fa fa-chevron-right"></i>';
                        echo '&nbsp;<span class="child">(' . sprintf( esc_html__( 'Page %s', 'offshore' ), esc_html( $paged ) ) . ')</span>';
                    } else {
                        echo '<span class="parent"><i class="fa fa-home"></i><a href="' . esc_url( get_home_url() ) . '">' . esc_html__( 'Home', 'offshore' ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        echo '<span class="child"><a href="' . esc_url( get_home_url() . '/?p=' . $blog_page_ID ) . '">' . esc_html__( 'Blog', 'offshore' ) . '</a></span><i class="fa fa-chevron-right"></i>';
                        echo '<span class="child">' . sprintf( esc_html__( 'Page %s', 'offshore' ), esc_html( $paged ) ) . '</span>';
                    }
                }

                echo '</div></div>';

            }
        
        }

    }

    add_action( 'offshore_content_before', 'offshore_breadcrumbs' );

}