<?php
/**
 * Build the meta tags and allow other people to filter them
 * @author Gautam Thapar
 * @since 1.0.0
 * @uses get_bloginfo(), has_filter(), apply_filters()
 *
 * Example on how to use 'offshore_meta_tags' filter to modify meta tags
 * add_filter( 'offshore_meta_tags', 'modify_tags' );
 * function modify_tags( $tags ){
 *     unset($tags['pingback']);
 *     return $tags;
 * }
 */
if( !function_exists('offshore_meta_tags') ){
    function offshore_meta_tags() {
        $tags = array(
            'encoding' => '<meta charset="' . esc_attr( get_bloginfo('charset') ) . '">',
            'iemode' => '<meta http-equiv="X-UA-Compatible" content="IE=edge">',
            'viewport' => '<meta name="viewport" content="width=device-width, initial-scale=1">',
            'description' => '<meta name="description" content="' . esc_attr( get_bloginfo('description') ) . '">'
        );
        // Author meta tag
        global $post;
        $author_id = null;
        $author = null;
        if (!is_404()) {
            // if there is no post author, this stuff doesn't exist
            if(isset($post)){
                if ( $post->post_author ) {
                    $author_id = $post->post_author;
                    $author = get_userdata($author_id);
                }
            }
            if ( $author ) {
                $tags['author'] = '<meta name="author" content="' . esc_attr( $author->display_name ) . '">';
            } // ends author check
        } // ends 404 check
        if ( is_singular() && pings_open( get_queried_object() ) ) {
            $tags['pingback'] = '<link rel="pingback" href="' . esc_url( get_bloginfo('pingback_url') ) . '" />';
        }
        $output = apply_filters( 'offshore_meta_tags', $tags, 10, 2 );
        foreach ($output as $key => $value) {
            echo $value . PHP_EOL;
        }
    }
}
// Hide/Display Meta Data
if( '0' == get_theme_mod( 'hide_metadata', '0' ) ){
    add_action( 'offshore_head_top', 'offshore_meta_tags' );
}