<?php
/**
* Offshore hook stub list.
*
* @package      offshore
* @version      1.0.0
* @since        1.0.0
* @license      http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License, v2 (or newer)
*/

/**
 * Themes and Plugins can check for offshore_hooks using current_theme_supports( 'offshore_hooks', $hook )
 * to determine whether a theme declares itself to support this specific hook type.
 *
 * Example:
 * <code>
 *      // Declare support for all hook types
 *      add_theme_support( 'offshore_hooks', array( 'all' ) );
 *
 *      // Declare support for certain hook types only
 *      add_theme_support( 'offshore_hooks', array( 'header', 'content', 'footer' ) );
 * </code>
 */
add_theme_support( 'offshore_hooks', array(

    /**
     * As a Theme developer, use the 'all' parameter, to declare support for all
     * hook types.
     * Please make sure you then actually reference all the hooks in this file,
     * Plugin developers depend on it!
     */
    'all',

    /**
     * Themes can also choose to only support certain hook types.
     * Please make sure you then actually reference all the hooks in this type
     * family.
     *
     * When the 'all' parameter was set, specific hook types do not need to be
     * added explicitly.
     */
    'html',
    'body',
    'head',
    'header',
    'content',
    'entry',
    'comments',
    'sidebars',
    'sidebar',
    'footer',

) );

/**
 * Determines, whether the specific hook type is actually supported.
 *
 * Plugin developers should always check for the support of a <strong>specific</strong>
 * hook type before hooking a callback function to a hook of this type.
 *
 * Example:
 * <code>
 *      if ( current_theme_supports( 'offshore_hooks', 'header' ) )
 *          add_action( 'offshore_head_top', 'prefix_header_top' );
 * </code>
 *
 * @param bool $bool true
 * @param array $args The hook type being checked
 * @param array $registered All registered hook types
 *
 * @return bool
 */
function offshore_current_theme_supports( $bool, $args, $registered ) {
    return in_array( $args[0], $registered[0] ) || in_array( 'all', $registered[0] );
}
add_filter( 'current_theme_supports-offshore_hooks', 'offshore_current_theme_supports', 10, 3 );

/**
 * HTML <html> hook
 * Special case, useful for <DOCTYPE>, etc.
 * $offshore_supports[] = 'html;
 */
 function offshore_html_before() {
     do_action( 'offshore_html_before' );
 }
/**
 * HTML <body> hooks
 * $offshore_supports[] = 'body';
 */
 function offshore_body_top() {
     do_action( 'offshore_body_top' );
     do_action( 'body_open' );
     do_action( 'before' );
 }

 function offshore_body_bottom() {
     do_action( 'offshore_body_bottom' );
 }

/**
* HTML <head> hooks
*
* $offshore_supports[] = 'head';
*/
function offshore_head_top() {
    do_action( 'offshore_head_top' );
}

function offshore_head_bottom() {
    do_action( 'offshore_head_bottom' );
}

/**
* Semantic <header> hooks
*
* $offshore_supports[] = 'header';
*/
function offshore_header_before() {
    do_action( 'offshore_header_before' );
}

function offshore_header_after() {
    do_action( 'offshore_header_after' );
}

function offshore_header_top() {
    do_action( 'offshore_header_top' );
}

function offshore_header_bottom() {
    do_action( 'offshore_header_bottom' );
}

/**
* Semantic <content> hooks
*
* $offshore_supports[] = 'content';
*/
function offshore_content_before() {
    do_action( 'offshore_content_before' );
}

function offshore_content_after() {
    do_action( 'offshore_content_after' );
}

function offshore_content_top() {
    do_action( 'offshore_content_top' );
}

function offshore_content_bottom() {
    do_action( 'offshore_content_bottom' );
}

/**
* Semantic <entry> hooks
*
* $offshore_supports[] = 'entry';
*/
function offshore_entry_before() {
    do_action( 'offshore_entry_before' );
}

function offshore_entry_after() {
    do_action( 'offshore_entry_after' );
}

function offshore_entry_top() {
    do_action( 'offshore_entry_top' );
}

function offshore_entry_bottom() {
    do_action( 'offshore_entry_bottom' );
}

/**
* Comments block hooks
*
* $offshore_supports[] = 'comments';
*/
function offshore_comments_before() {
    do_action( 'offshore_comments_before' );
}

function offshore_comments_after() {
    do_action( 'offshore_comments_after' );
}

/**
* Semantic <sidebar> hooks
*
* $offshore_supports[] = 'sidebar';
*/
function offshore_sidebars_before() {
    do_action( 'offshore_sidebars_before' );
}

function offshore_sidebars_after() {
    do_action( 'offshore_sidebars_after' );
}

function offshore_sidebar_top() {
    do_action( 'offshore_sidebar_top' );
}

function offshore_sidebar_bottom() {
    do_action( 'offshore_sidebar_bottom' );
}

/**
* Semantic <footer> hooks
*
* $offshore_supports[] = 'footer';
*/
function offshore_footer_before() {
    do_action( 'offshore_footer_before' );
}

function offshore_footer_after() {
    do_action( 'offshore_footer_after' );
}

function offshore_footer_top() {
    do_action( 'offshore_footer_top' );
}

function offshore_footer_bottom() {
    do_action( 'offshore_footer_bottom' );
}