<?php 

/**
 * Load styles
 * @since 1.0.0
 * @author Gautam Thapar
 * @uses wp_register_style(), wp_enqueue_style(), get_stylesheet_uri()
 * 
 * loads all the styles for the theme
*/
if(!function_exists('offshore_load_styles')) {
    function offshore_load_styles() {
        wp_enqueue_style( 'offshore-fonts', offshore_fonts_url(), false, OFFSHORE_PARENT_THEME_VERSION );
        wp_enqueue_style( 'bootstrap', OFFSHORE_CSS_URL . '/bootstrap.min.css', false, '3.3.5' );
        wp_enqueue_style( 'fontawesome', OFFSHORE_CSS_URL . '/font-awesome.min.css', false, '4.6.3' );
        wp_enqueue_style( 'flexslider', OFFSHORE_CSS_URL . '/flexslider.css', false, '2.6.0' );
        wp_enqueue_style( 'owlcarousel', OFFSHORE_CSS_URL . '/owl.carousel.min.css', false, '2.1.1' );
        wp_enqueue_style( 'offshore-main', get_stylesheet_uri(), array( 'bootstrap', 'owlcarousel', 'fontawesome' ), OFFSHORE_PARENT_THEME_VERSION );

        // this loads jquery (for bootstrap, among other things)
        wp_enqueue_script( 'jquery' );
        // load boostrap
        wp_enqueue_script( 'bootstrap', OFFSHORE_JS_URL . '/bootstrap.min.js', array( 'jquery' ), '3.3.5', true );
        // loads flexslider
        wp_enqueue_script( 'flexslider', OFFSHORE_JS_URL . '/jquery.flexslider-min.js', true, '2.6.0' );
        // loads back to top script
        wp_enqueue_script( 'backtotop', OFFSHORE_JS_URL . '/back-to-top.js', true, '1.0.0' );
        // loads mailchimp newsletter script
        wp_enqueue_script( 'mailchimp', OFFSHORE_JS_URL . '/jquery.ajaxchimp.min.js', true, '1.3.0' );
        // loads waypoints js
        wp_enqueue_script( 'waypoints', OFFSHORE_JS_URL . '/waypoints.min.js', true, '2.0.3' );
        // loads counter js
        wp_enqueue_script( 'counterup', OFFSHORE_JS_URL . '/jquery.counterup.min.js', true, '1.0' );
        // loads owl carousel js
        wp_enqueue_script( 'owlcarousel', OFFSHORE_JS_URL . '/owl.carousel.min.js', true, '2.1.1' );
        // loads google maps js
        $gmaps_api_key = '?key=' . get_theme_mod( 'gmaps_api_key', '' );
        wp_enqueue_script( 'google-maps', 'https://maps.googleapis.com/maps/api/js' . $gmaps_api_key, '', false, true );
        // loads maps js
        wp_enqueue_script( 'google-map-tabs', OFFSHORE_JS_URL . '/maps.js', 'google-maps', false, true );
        // loads the comment reply script
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
    }
}
add_action( 'wp_enqueue_scripts', 'offshore_load_styles' );

/**
 * Register fonts.
 * https://gist.github.com/kailoon/e2dc2a04a8bd5034682c
 * @since 1.0.2
 */
function offshore_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
    */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'offshore' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Roboto:300,400,500,700|Roboto Condensed:400,700' ), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 * @since 1.0.0
 */
function offshore_customize_preview_js() {
    wp_enqueue_script( 'Offshore_customizer', OFFSHORE_JS_URL . '/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'offshore_customize_preview_js' );

/**
 * Add header image to head section
 * @since 1.0.0
 * @author Gautam Thapar
*/
if( !function_exists('offshore_custom_css') ) {
    function offshore_custom_css() {
        ?>
            <style type="text/css">
                .page-title {
                    background: url('<?php header_image(); ?>') no-repeat left center;
                }
            </style>
        <?php
    }
    add_action( 'wp_head', 'offshore_custom_css' );
}


/**
* Passes custom typography classes to Tiny MCE editor
* @since 1.0.3
* @param    $offshore_mceInit                       array
* @return   $offshore_mceInit                       array
*/
function offshore_tiny_mce_classes( $offshore_mceInit ) {
    /**
     * $offshore_mceInit array stores its body classes as a string
     *
     * Whitespace character is used as separator between classes,
     * so when adding classes they must have a space before them
     */
    $offshore_mceInit['body_class'] .= ' offshore-body-typography';         // Body font class
    $offshore_mceInit['body_class'] .= ' offshore-h1-typography';   // H1 font class
 
    return $offshore_mceInit;
}
add_filter( 'tiny_mce_before_init', 'offshore_tiny_mce_classes' );

/**
 * Load Google Fonts to use in Tiny MCE
 * @since 1.0.3
 * @param   $mce_css                            string
 * @return  $mce_css                            string
 */
function offshore_mce_css( $mce_css ) {
    $url = offshore_fonts_url();
    $mce_css .= ', '.$url;
    return $mce_css;
}
add_filter( 'mce_css', 'offshore_mce_css' );

